blueprint_auth library

Classes

AuthController
Central auth controller. Handles both AuthMethod.phone and AuthMethod.email.
AuthControllerProvider
Central auth controller. Handles both AuthMethod.phone and AuthMethod.email.
AuthFlowScreen
AuthState
Immutable snapshot of the current auth session.
AuthStepLayout
Visual layout for an auth step shell.
AuthStepTemplate
Presentation template for a single auth-flow step.
AuthStepTemplates
Registry of customizable auth step presentation templates.
AuthStorage
Persists the refresh token and user profile to secure storage.
DefaultEmailStepTemplate
DefaultForgotPasswordStepTemplate
DefaultOtpStepTemplate
DefaultPhoneStepTemplate
DefaultResetPasswordStepTemplate
DefaultSignupStepTemplate
DefaultVerifyResetPasswordStepTemplate
EmailStepTemplate
ForgotPasswordStepTemplate
FxSignupFormGroup
OtpStepTemplate
PhoneStepTemplate
ResetPasswordStepTemplate
SignupStepTemplate
User
Represents an authenticated user decoded from the JWT payload and/or fetched from GET /users/me.
VerifyResetPasswordStepTemplate

Enums

AuthMethod
The authentication method the server is configured to use. Set this once in app/config/app_config.dart.
AuthStatus
Status of the current authentication session.
FxNameLayout

Extensions

AuthStatePatterns on AuthState
Adds pattern-matching-related methods to AuthState.
AuthStepNavigation on WidgetRef
Navigation helper for step templates and footers.
UserPatterns on User
Adds pattern-matching-related methods to User.

Properties

authControllerProvider AuthControllerProvider
Central auth controller. Handles both AuthMethod.phone and AuthMethod.email.
final