AuthControllerProvider class final
Central auth controller. Handles both AuthMethod.phone and AuthMethod.email.
Delegates each domain to a focused mixin:
- Phone OTP flow →
_PhoneAuthMixin - Email + password →
_EmailAuthMixin - Password reset / change →
_PasswordMixin - Session management →
_SessionMixin - Invite acceptance →
_InviteMixin
Inject via: ref.watch(authControllerProvider)
State: AuthState
Properties
- argument → Object?
-
If this provider was created with the
.familymodifier,argumentis the variable that was used.finalinherited -
dependencies
→ Iterable<
ProviderOrFamily> ? -
The list of providers that this provider potentially depends on.
finalinherited
- from → Family?
-
If this provider was created with the
.familymodifier,fromis the.familyinstance.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- isAutoDispose → bool
-
Whether the state associated to this provider should be disposed
automatically when the provider stops being listened.
finalinherited
- name → String?
-
A custom label for providers.
finalinherited
-
notifier
→ Refreshable<
AuthController> -
no setterinherited
-
origin
→ ProviderBase<
AuthState> -
The provider that is overridden.
no setterinherited
- retry → Retry?
-
The retry strategy to use when a provider fails.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
) → AuthController - @nodoc
-
debugGetCreateSourceHash(
) → String - A debug-only function for obtaining a hash of the source code of the initialization function.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overrideWith(
AuthController create()) → Override -
Override the provider with a new initialization function.
inherited
-
overrideWithBuild(
RunNotifierBuild< AuthController, AuthState> build) → Override -
Overrides the
buildmethod of a notifier, allowing you to replace the default implementation with a custom one for testing or specific use cases.inherited -
overrideWithValue(
AuthState value) → Override - Overrides a provider with a value, ejecting the default behavior.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited