AuthMethod enum

The authentication method the server is configured to use. Set this once in app/config/app_config.dart.

Inheritance
Available extensions

Values

phone → const AuthMethod

Phone number + OTP flow (AUTH_METHOD=phone on the server).

email → const AuthMethod

Email + password flow (AUTH_METHOD=email on the server).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthMethod>
A constant List of the values in this enum, in order of their declaration.