AuthSession class abstract

A user's active device session from GET /auth/sessions.

Available extensions
Annotations
  • @freezed

Constructors

AuthSession({required String id, required String deviceInfo, required String ipAddress, required String createdAt, required String expiresAt})
const
factory
AuthSession.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $AuthSessionCopyWith<AuthSession>
Create a copy of AuthSession with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt String
no setterinherited
deviceInfo String
no setterinherited
expiresAt String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
ipAddress String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AuthSession value)) → TResult

Available on AuthSession, provided by the AuthSessionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AuthSession value)?) → TResult?

Available on AuthSession, provided by the AuthSessionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AuthSession value)?, {required TResult orElse()}) → TResult

Available on AuthSession, provided by the AuthSessionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String deviceInfo, String ipAddress, String createdAt, String expiresAt)?, {required TResult orElse()}) → TResult

Available on AuthSession, provided by the AuthSessionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AuthSession to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String deviceInfo, String ipAddress, String createdAt, String expiresAt)) → TResult

Available on AuthSession, provided by the AuthSessionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String deviceInfo, String ipAddress, String createdAt, String expiresAt)?) → TResult?

Available on AuthSession, provided by the AuthSessionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited