DefaultEmailStepTemplate class
- Inheritance
-
- Object
- AuthStepTemplate
- EmailStepTemplate
- DefaultEmailStepTemplate
Constructors
- DefaultEmailStepTemplate({BuildContext? context, WidgetRef? ref})
-
const
Properties
- actionLabel → String
-
Convenience accessors for step screens.
no setterinherited
- buildAppBar → PreferredSizeWidget?
-
Optional app bar for this step.
no setterinherited
-
Optional sticky footer below scroll content.
no setterinherited
- buildTrailingContent → Widget?
-
Optional content appended after the main body.
no setterinherited
- context → BuildContext
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → AuthStepLayout
-
Layout defaults for this step.
no setterinherited
- ref → WidgetRef
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepId → String
-
Stable step identity — not a Flutter Key.
no setterinherited
- subtitle → String?
-
no setterinherited
- title → String?
-
no setterinherited
Methods
-
buildShell(
{Widget? body, List< Widget> ? children, }) → Widget -
Wraps
bodyin the shared auth step shell.inherited -
copyWith(
{required BuildContext context, required WidgetRef ref}) → EmailStepTemplate -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onSignUpRequested(
WidgetRef ref) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited