EmailAuthFlowController class

Manages the email auth flow (login and register steps). Delegates all API calls to authControllerProvider.

Annotations
  • @riverpod

Constructors

EmailAuthFlowController()

Properties

hashCode int
The hash code for this object.
no setterinherited
ref → Ref
The Ref associated with this notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state EmailAuthFlowState
The value currently exposed by this notifier.
getter/setter pairinherited
stateOrNull EmailAuthFlowState?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() EmailAuthFlowState
goToStep(FxEmailAuthStep step) → void
listenSelf(void listener(EmailAuthFlowState? previous, EmailAuthFlowState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
login({required String email, required String password}) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerWithEmail(EmailRegisterRequest request) Future<bool>
runBuild() → void
Executes Notifier.build.
inherited
toString() String
A string representation of this object.
inherited
updateShouldNotify(EmailAuthFlowState previous, EmailAuthFlowState next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited