EmailAuthFlowState class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- EmailAuthFlowState({String? email, @Default.new(FxEmailAuthStep.login) FxEmailAuthStep step, @Default.new(false) bool isLoading, String? error})
-
constfactory
Properties
-
copyWith
→ $EmailAuthFlowStateCopyWith<
EmailAuthFlowState> -
Create a copy of EmailAuthFlowState
with the given fields replaced by the non-null parameter values.
no setterinherited
- email → String?
-
no setterinherited
- error → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- step → FxEmailAuthStep
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EmailAuthFlowState value)) → TResult -
Available on EmailAuthFlowState, provided by the EmailAuthFlowStatePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EmailAuthFlowState value)?) → TResult? -
Available on EmailAuthFlowState, provided by the EmailAuthFlowStatePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EmailAuthFlowState value)?, {required TResult orElse()}) → TResult -
Available on EmailAuthFlowState, provided by the EmailAuthFlowStatePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? email, FxEmailAuthStep step, bool isLoading, String? error)?, {required TResult orElse()}) → TResult -
Available on EmailAuthFlowState, provided by the EmailAuthFlowStatePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? email, FxEmailAuthStep step, bool isLoading, String? error)) → TResult -
Available on EmailAuthFlowState, provided by the EmailAuthFlowStatePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? email, FxEmailAuthStep step, bool isLoading, String? error)?) → TResult? -
Available on EmailAuthFlowState, provided by the EmailAuthFlowStatePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited