EmailAuthService class

Handles all OTP-specific API calls for the phone auth flow.

Inheritance

Constructors

EmailAuthService(ServiceContext ctx)

Properties

dio → Dio
finalinherited
endpoints ApiEndpoints
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forgotPassword(String email) Future<void>
login({required String email, required String password}) Future<AuthTokens>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetPassword({required String token, required String newPassword}) Future<void>
resetPasswordViaPhone({required String phoneGrantToken, required String newPassword}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited