layout property
Layout defaults for this step.
Implementation
@override
AuthStepLayout get layout => const AuthStepLayout(
title: 'Enter your email',
subtitle: 'We will send you a code to verify your email',
actionLabel: 'Log in',
);
Layout defaults for this step.
@override
AuthStepLayout get layout => const AuthStepLayout(
title: 'Enter your email',
subtitle: 'We will send you a code to verify your email',
actionLabel: 'Log in',
);