ForgotPasswordFlowState class abstract

Available extensions
Annotations
  • @freezed

Constructors

ForgotPasswordFlowState({@Default.new(ForgotPasswordStep.enterEmail) ForgotPasswordStep step, String? email, String? resetToken, @Default.new(false) bool isLoading, String? error})
const
factory

Properties

copyWith → $ForgotPasswordFlowStateCopyWith<ForgotPasswordFlowState>
Create a copy of ForgotPasswordFlowState with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
The email entered in step 1, carried into step 2 for display.
no setterinherited
error String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
no setterinherited
resetToken String?
The reset token received after pin verification, used in step 3.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step ForgotPasswordStep
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ForgotPasswordFlowState value)) → TResult

Available on ForgotPasswordFlowState, provided by the ForgotPasswordFlowStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ForgotPasswordFlowState value)?) → TResult?

Available on ForgotPasswordFlowState, provided by the ForgotPasswordFlowStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ForgotPasswordFlowState value)?, {required TResult orElse()}) → TResult

Available on ForgotPasswordFlowState, provided by the ForgotPasswordFlowStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ForgotPasswordStep step, String? email, String? resetToken, bool isLoading, String? error)?, {required TResult orElse()}) → TResult

Available on ForgotPasswordFlowState, provided by the ForgotPasswordFlowStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ForgotPasswordStep step, String? email, String? resetToken, bool isLoading, String? error)) → TResult

Available on ForgotPasswordFlowState, provided by the ForgotPasswordFlowStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ForgotPasswordStep step, String? email, String? resetToken, bool isLoading, String? error)?) → TResult?

Available on ForgotPasswordFlowState, provided by the ForgotPasswordFlowStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited