resetToken property

String? get resetToken
inherited

The reset token received after pin verification, used in step 3.

Implementation

String? get email;/// The reset token received after pin verification, used in step 3.
String? get resetToken;