FxEmailAuthTheme class
Constructors
- FxEmailAuthTheme({Widget loginBuilder(BuildContext context)?, Widget registerBuilder(BuildContext context)?, bool showInputLabel = false, LoginConfig loginConfig = const LoginConfig(), RegisterConfig registerConfig = const RegisterConfig()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- loginBuilder → Widget Function(BuildContext context)?
-
final
- loginConfig → LoginConfig
-
final
- registerBuilder → Widget Function(BuildContext context)?
-
final
- registerConfig → RegisterConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showInputLabel → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited