FxOtpInputState class
- Inheritance
-
- Mixed-in types
-
Methods
-
activate()
→ void
-
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
override
-
deactivate()
→ void
-
Called when this object is removed from the tree.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
didChangeDependencies()
→ void
-
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(covariant FxOtpInput oldWidget)
→ void
-
Called whenever the widget configuration changes.
inherited
-
dispose()
→ void
-
Called when this object is removed from the tree permanently.
inherited
-
initState()
→ void
-
Called when this object is inserted into the tree.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<T>([T? result])
→ void
-
Pops the current route off the stack.
inherited
-
push(String route)
→ void
-
Pushes a named route onto the stack.
inherited
-
pushAndClearStack(String route)
→ void
-
Clears the entire stack and pushes a named route.
inherited
-
pushReplace(String route)
→ void
-
Replaces the current route with a named route.
inherited
-
reassemble()
→ void
-
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(VoidCallback fn)
→ void
-
Notify the framework that the internal state of this object has changed.
inherited
-
setToolkitContext(BuildContext ctx)
→ void
-
inherited
-
showFxBottomSheet<T>({bool cancelable = true, bool allowFullHeight = true, double maxChildSize = 0.9, double minChildSize = 0.25, double initialChildSize = 0.5, required FxOverlayData<T> data})
→ Future<T?>
-
Shows the blueprint bottom sheet.
inherited
-
showFxDialog<T>({bool cancelable = true, FxDialogStyle style = FxDialogStyle.center, required FxOverlayData<T> data})
→ Future<T?>
-
Shows the blueprint dialog.
inherited
-
showSnackBar(SnackBar snackBar)
→ void
-
Shows a snack bar.
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toggleTheme(WidgetRef ref)
→ void
-
Toggles the theme between light and dark mode.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringShort()
→ String
-
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
triggerError()
→ void
-
Clears all cells and triggers the shake animation.
-
unfocus()
→ void
-
Unfocuses the current focus node.
inherited