FxSignupFormGroup class

Inheritance

Constructors

FxSignupFormGroup({Map<String, FxFormControl> controls = const {}})
const
FxSignupFormGroup.initial()

Properties

confirmPassword FxFormControl
no setter
controls Map<String, FxFormControl>
no setterinherited
countryCode FxFormControl
no setter
dateOfBirth FxFormControl
no setter
email FxFormControl
no setter
firstName FxFormControl
no setter
fullNumber FxFormControl
no setter
gender FxFormControl
no setter
hashCode int
The hash code for this object.
no setterinherited
lastName FxFormControl
no setter
password FxFormControl
no setter
phone FxFormControl
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username FxFormControl
no setter

Methods

copyWith(Map<String, FxFormControl> controls) FxSignupFormGroup
override
dispose() → void
inherited
getControl(String key) FxFormControl
inherited
hidePassword() FxSignupFormGroup
initState() FxSignupFormGroup
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(String key, String value) → void
inherited
setValues({String? phone, String? email}) → void
toString() String
A string representation of this object.
inherited
updateControl(String key, FxFormControl updater(FxFormControl value)) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited