LoginConfig class

Phone entry

Constructors

LoginConfig({String title = 'Login', String subtitle = 'Enter your email and password to login', Widget? emailPrefix, Widget? passwordPrefix, String forgotPasswordLabel = 'Forgot password?', String noAccountLabel = "Don't have an account?", String signUpLabel = 'Sign up', String buttonLabel = 'Login'})
const

Properties

buttonLabel String
The button label for the login button.
final
emailPrefix Widget?
The prefix widget for the email input.
final
forgotPasswordLabel String
The label text for the forgot password button.
final
hashCode int
The hash code for this object.
no setterinherited
noAccountLabel String
The label text for the no account button.
final
passwordPrefix Widget?
The label text for the password input.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signUpLabel String
The label text for the sign up button.
final
subtitle String
The subtitle text for the phone entry screen.
final
title String
The title text for the phone entry screen.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited