OtpDataResponse class

Payload in the data field from POST /auth/send-otp (and resend).

Annotations
  • @JsonSerializable.new()

Constructors

OtpDataResponse({required String verificationId, required int expiresAt, required int resendIn})
const
OtpDataResponse.fromJson(Map<String, dynamic> json)
factory

Properties

expiresAt int
final
hashCode int
The hash code for this object.
no setterinherited
resendIn int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verificationId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited