OtpVerificationConfig class

Verify phone (OTP)

Constructors

OtpVerificationConfig({int otpLength = 6, String? title = 'Verify your number', String? subtitle = 'Enter the code sent to {{phone}}', String buttonLabel = 'Verify', String changeNumberLabel = 'Change number', int resendCooldownSeconds = 60, String resendPrefixText = "Didn't receive a code?", String resendActionText = 'Resend', String resendCountdownPrefixText = 'Resend in', String invalidCodeMessage = 'Invalid code, please try again', String expiredCodeMessage = 'Code expired, please request a new one', Widget keyboardBuilder(TextEditingController phoneController)?, Widget header(String phone, VoidCallback onChangeNumber)?, FxTextStyle? titleStyle, FxTextStyle? subtitleStyle, Widget footer(VoidCallback onChangeNumber)?, EdgeInsets? padding, double? spacing, double? titleSpacing, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.stretch})
const

Properties

buttonLabel String
The button label for the verify button.
final
changeNumberLabel String
The label for the change number button.
final
crossAxisAlignment CrossAxisAlignment
The cross axis alignment for the otp verification screen.
final
expiredCodeMessage String
The message text for the expired code.
final
The footer widget for the otp verification screen.
final
hashCode int
The hash code for this object.
no setterinherited
The header widget for the otp verification screen.
final
invalidCodeMessage String
The message text for the invalid code.
final
keyboardBuilder Widget Function(TextEditingController phoneController)?
The keyboard builder for the otp verification screen.
final
mainAxisAlignment MainAxisAlignment
The main axis alignment for the otp verification screen.
final
otpLength int
The length of the otp code.
final
padding EdgeInsets?
The padding for the otp verification screen.
final
resendActionText String
The action text for the resend code button.
final
resendCooldownSeconds int
The cooldown seconds for the resend code button.
final
resendCountdownPrefixText String
The prefix text for the resend countdown.
final
resendPrefixText String
The prefix text for the resend code button.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double?
The spacing for the otp verification screen.
final
subtitle String?
The subtitle text with {{phone}} placeholder for the phone number. Example: 'Enter the code sent to {{phone}}'
final
subtitleStyle FxTextStyle?
final
title String?
The title text for the otp verification screen.
final
titleSpacing double?
final
titleStyle FxTextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited