PhoneAuthFlowController class
- Annotations
-
- @riverpod
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
The
Refassociated with this notifier.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ PhoneAuthFlowState
-
The value currently exposed by this notifier.
getter/setter pairinherited
- stateOrNull → PhoneAuthFlowState?
-
The value currently exposed by this
Notifier.no setterinherited
Methods
-
build(
) → PhoneAuthFlowState -
goBack(
) → void -
listenSelf(
void listener(PhoneAuthFlowState? previous, PhoneAuthFlowState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
{required String firstName, required String lastName, String? email}) → Future< void> -
resendOtp(
) → Future< void> -
runBuild(
) → void -
Executes
Notifier.build.inherited -
sendOtp(
String phone) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
PhoneAuthFlowState previous, PhoneAuthFlowState next) → bool -
A method invoked when the state exposed by this
Notifierchanges. It compares the previous and new value, and return whether listeners should be notified.inherited -
verifyOtp(
String code) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited