PhoneLookupResult class abstract
Result of POST /auth/verify-otp. Branches based on whether the user already has an account.
- Available extensions
- Annotations
-
- @freezed
Constructors
- PhoneLookupResult({required bool success, required String message, required PhoneLookupDataResponse data})
-
constfactory
-
PhoneLookupResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $PhoneLookupResultCopyWith<
PhoneLookupResult> -
Create a copy of PhoneLookupResult
with the given fields replaced by the non-null parameter values.
no setterinherited
- data → PhoneLookupDataResponse
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_PhoneLookupResult value)) → TResult -
Available on PhoneLookupResult, provided by the PhoneLookupResultPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_PhoneLookupResult value)?) → TResult? -
Available on PhoneLookupResult, provided by the PhoneLookupResultPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_PhoneLookupResult value)?, {required TResult orElse()}) → TResult -
Available on PhoneLookupResult, provided by the PhoneLookupResultPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(bool success, String message, PhoneLookupDataResponse data)?, {required TResult orElse()}) → TResult -
Available on PhoneLookupResult, provided by the PhoneLookupResultPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PhoneLookupResult to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(bool success, String message, PhoneLookupDataResponse data)) → TResult -
Available on PhoneLookupResult, provided by the PhoneLookupResultPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(bool success, String message, PhoneLookupDataResponse data)?) → TResult? -
Available on PhoneLookupResult, provided by the PhoneLookupResultPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited