ResetPasswordInput class

Input data for the password reset step.

Constructors

ResetPasswordInput({required String resetToken, required String newPassword, required String confirmPassword})
const

Properties

confirmPassword String
final
hashCode int
The hash code for this object.
no setterinherited
newPassword String
final
resetToken String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited