User class abstract
Represents an authenticated user decoded from the JWT payload and/or fetched from GET /users/me.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
User({required String id, required int onboardingStep, required bool isEmailVerified, required bool isPhoneVerified, required bool isProfileCompleted, required String status, required String displayName, String? firstName, String? lastName, String? username, String? email, String? phoneNumber, String? countryCode, @Default.new([]) List<
String> roles}) -
constfactory
-
User.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $UserCopyWith<
User> -
Create a copy of User
with the given fields replaced by the non-null parameter values.
no setterinherited
- countryCode → String?
-
no setterinherited
- displayName → String
-
no setterinherited
- email → String?
-
no setterinherited
- firstName → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- isEmailVerified → bool
-
no setterinherited
- isPhoneVerified → bool
-
no setterinherited
- isProfileCompleted → bool
-
no setterinherited
- lastName → String?
-
no setterinherited
- onboardingStep → int
-
no setterinherited
- phoneNumber → String?
-
no setterinherited
-
roles
→ List<
String> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
no setterinherited
- username → String?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_User value)) → TResult -
Available on User, provided by the UserPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_User value)?) → TResult? -
Available on User, provided by the UserPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_User value)?, {required TResult orElse()}) → TResult -
Available on User, provided by the UserPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, int onboardingStep, bool isEmailVerified, bool isPhoneVerified, bool isProfileCompleted, String status, String displayName, String? firstName, String? lastName, String? username, String? email, String? phoneNumber, String? countryCode, List< String> roles)?, {required TResult orElse()}) → TResult -
Available on User, provided by the UserPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this User to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, int onboardingStep, bool isEmailVerified, bool isPhoneVerified, bool isProfileCompleted, String status, String displayName, String? firstName, String? lastName, String? username, String? email, String? phoneNumber, String? countryCode, List< String> roles)) → TResult -
Available on User, provided by the UserPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, int onboardingStep, bool isEmailVerified, bool isPhoneVerified, bool isProfileCompleted, String status, String displayName, String? firstName, String? lastName, String? username, String? email, String? phoneNumber, String? countryCode, List< String> roles)?) → TResult? -
Available on User, provided by the UserPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited