UserDetailsInput class

Constructors

UserDetailsInput({required String firstName, required String lastName, String? email})
const

Properties

email String?
The email input.
final
firstName String
The first name input.
final
hashCode int
The hash code for this object.
no setterinherited
lastName String
The last name input.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited