FxAssetIcon class

Constructors

FxAssetIcon({required String name})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
path String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
svg({double? width, double? height, ColorFilter? colorFilter, Color? color, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, String? semanticsLabel, WidgetBuilder? placeholderBuilder, String? package, bool matchTextDirection = false, bool allowDrawingOutsideViewBox = false}) → SvgPicture
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited