ErrorMapper class abstract final

Maps raw DioExceptions into typed NetworkException or UnauthorizedException errors that the rest of the app can handle.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isNetworkError(DioException e) bool
map(DioException err) → DioException
unauthorized(RequestOptions options) → DioException