FxError class abstract

Available extensions
Annotations
  • @freezed

Constructors

FxError({required String message, String? code, int? statusCode})
const
factory
FxError.fromJson(Map<String, dynamic> json)
factory

Properties

code String?
no setterinherited
copyWith → $FxErrorCopyWith<FxError>
Create a copy of FxError with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
message String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FxError value)) → TResult

Available on FxError, provided by the FxErrorPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FxError value)?) → TResult?

Available on FxError, provided by the FxErrorPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FxError value)?, {required TResult orElse()}) → TResult

Available on FxError, provided by the FxErrorPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String message, String? code, int? statusCode)?, {required TResult orElse()}) → TResult

Available on FxError, provided by the FxErrorPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FxError to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String message, String? code, int? statusCode)) → TResult

Available on FxError, provided by the FxErrorPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String message, String? code, int? statusCode)?) → TResult?

Available on FxError, provided by the FxErrorPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited