FxHeadersInterceptor class

Adds enterprise-oriented headers on every outbound request.

Generates fresh X-Request-Id, X-Correlation-Id, and X-Client-Trace-Id per HTTP call. Set FxRequestExtras.idempotencyKey in Options.extra when the backend expects an idempotency token for mutating calls.

Constructors

FxHeadersInterceptor(FxConfig _config)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
inherited
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited