FxNotificationController class
- Mixed-in types
- Annotations
-
- @riverpod
Constructors
Properties
- canRegisterDevice → bool
-
no setter
- config → FxConfig
-
Shorthand for the app config.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceContext → FxServiceContext
-
Shorthand for the shared service context (dio + endpoints).
no setterinherited
- state ↔ FxNotificationsState
-
The value currently exposed by this notifier.
getter/setter pairinherited
- stateOrNull → FxNotificationsState?
-
The value currently exposed by this
Notifier.no setterinherited
Methods
-
build(
) → FxNotificationsState -
deleteNotification(
String id) → Future< void> -
listenSelf(
void listener(FxNotificationsState? previous, FxNotificationsState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
loadNotifications(
{bool refresh = false}) → Future< void> -
loadUnreadCount(
) → Future< void> -
markAllAsRead(
) → Future< void> -
markAsRead(
String id) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerDevice(
String token) → Future< void> -
requestNotificationPermission(
) → Future< void> -
resolveError(
Object e) → String -
Converts a caught exception into a user-facing message.
inherited
-
runBuild(
) → void -
Executes
Notifier.build.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
FxNotificationsState previous, FxNotificationsState next) → bool -
A method invoked when the state exposed by this
Notifierchanges. It compares the previous and new value, and return whether listeners should be notified.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited