NotificationService class
- Inheritance
-
- Object
- AppService
- NotificationService
Constructors
Properties
- dio → Dio
-
finalinherited
- endpoints → FxApiEndpoints
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteNotification(
String id) → Future< void> -
getNotifications(
{int page = 1, int limit = 20}) → Future< PaginatedResponse< AppNotification> > -
getUnreadCount(
) → Future< int> -
markAllAsRead(
) → Future< void> -
markAsRead(
String id) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerDevice(
DeviceRegistration device) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterDevice(
String fcmToken) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited