ProfileController class

Mixed-in types
Annotations
  • @riverpod

Constructors

ProfileController()

Properties

config AppConfig
Shorthand for the app config.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ref → Ref
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceContext ServiceContext
Shorthand for the shared service context (dio + endpoints).
no setterinherited
state ProfileState
The value currently exposed by this notifier.
getter/setter pairinherited
stateOrNull ProfileState?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() ProfileState
clearError() → void
listenSelf(void listener(ProfileState? previous, ProfileState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
loadProfile() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveError(Object e) String
Converts a caught exception into a user-facing message.
inherited
runBuild() → void
Executes Notifier.build.
inherited
toString() String
A string representation of this object.
inherited
updateProfile(ProfileUpdate update) Future<bool>
updateShouldNotify(ProfileState previous, ProfileState next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited