ProfileService class
- Inheritance
-
- Object
- AppService
- ProfileService
Constructors
- ProfileService(ServiceContext serviceContext)
Properties
- dio → Dio
-
finalinherited
- endpoints → ApiEndpoints
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMe(
) → Future< AuthUser> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateMe(
ProfileUpdate update) → Future< AuthUser>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited