ProfileUpdate class abstract
Body for PATCH /users/me
- Available extensions
- Annotations
-
- @freezed
Constructors
- ProfileUpdate({String? firstName, String? lastName, String? email})
-
constfactory
-
ProfileUpdate.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $ProfileUpdateCopyWith<
ProfileUpdate> -
Create a copy of ProfileUpdate
with the given fields replaced by the non-null parameter values.
no setterinherited
- email → String?
-
no setterinherited
- firstName → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ProfileUpdate value)) → TResult -
Available on ProfileUpdate, provided by the ProfileUpdatePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ProfileUpdate value)?) → TResult? -
Available on ProfileUpdate, provided by the ProfileUpdatePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ProfileUpdate value)?, {required TResult orElse()}) → TResult -
Available on ProfileUpdate, provided by the ProfileUpdatePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? firstName, String? lastName, String? email)?, {required TResult orElse()}) → TResult -
Available on ProfileUpdate, provided by the ProfileUpdatePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ProfileUpdate to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? firstName, String? lastName, String? email)) → TResult -
Available on ProfileUpdate, provided by the ProfileUpdatePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? firstName, String? lastName, String? email)?) → TResult? -
Available on ProfileUpdate, provided by the ProfileUpdatePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited