FxTheme class abstract

Blueprint theme builder.

Extend this once in app/theme/app_theme.dart — never edit this file. Override appColors, appSizes, appTypography, and appThemeData to wire your brand into the full Material ThemeData.

Constructors

FxTheme()

Properties

appColors FxColors
no setter
appComponentTheme FxComponentTheme
no setter
appSizes FxSizes
no setter
appThemeData FxThemeData
no setter
appTypography FxTypography
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(Brightness brightness) ThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited