FxThemeData class abstract
Blueprint contract for Material sub-theme builders.
Extend this in app/theme/app_theme_data.dart to override any sub-theme.
All getters receive brightness-resolved colors, sizes, and typography
from FxTheme.build — never construct raw colors here.
- Inheritance
-
- Object
- ThemeExtension<
FxThemeData> - FxThemeData
Constructors
- FxThemeData({required FxColors colors, required FxSizes sizes, required FxTypography typography})
-
const
Properties
- appBarTheme → AppBarTheme
-
no setter
- bottomSheetTheme → BottomSheetThemeData
-
no setter
- cardTheme → CardThemeData
-
no setter
- checkboxTheme → CheckboxThemeData
-
no setter
- chipTheme → ChipThemeData
-
no setter
- colors → FxColors
-
final
- dialogTheme → DialogThemeData
-
no setter
- dividerTheme → DividerThemeData
-
no setter
- elevatedButtonTheme → ElevatedButtonThemeData
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputDecorationTheme → InputDecorationTheme
-
no setter
- keyboardTheme → FxKeyboardTheme
-
no setter
- outlinedButtonTheme → OutlinedButtonThemeData
-
no setter
- overlayTheme → FxOverlayThemeData
-
no setter
- overlayTileTheme → FxOverlayTileThemeData
-
no setter
- phoneInputTheme → FxPhoneInputTheme
-
no setter
- pinInputTheme → FxPinInputTheme
-
no setter
- progressIndicatorTheme → ProgressIndicatorThemeData
-
no setter
- radioTheme → RadioThemeData
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizes → FxSizes
-
final
- snackBarTheme → SnackBarThemeData
-
no setter
- switchTheme → SwitchThemeData
-
no setter
- textButtonTheme → TextButtonThemeData
-
no setter
- tooltipTheme → TooltipThemeData
-
no setter
- type → Object
-
The extension's type.
no setterinherited
- typography → FxTypography
-
final
Methods
-
copyWith(
{FxColors? colors, FxSizes? sizes, FxTypography? typography}) → FxThemeData -
Returns a copy with updated fields.
Called by FxTheme.build with brightness-resolved instances.
override
-
lerp(
covariant FxThemeData? other, double t) → FxThemeData -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited