FxAppBarStyle class

Constructors

FxAppBarStyle({Widget? titleWidget, List<Widget>? actions, Widget? leading, bool centerTitle = true, double elevation = 0, Color? backgroundColor, Color? foregroundColor, bool automaticallyImplyLeading = true})
const

Properties

actions List<Widget>?
final
automaticallyImplyLeading bool
final
backgroundColor Color?
final
centerTitle bool
final
elevation double
final
foregroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
leading Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleWidget Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited