FxDottedDividerThemeData class

Constructors

FxDottedDividerThemeData({Color? color, double? strokeWidth = 1, double? dashWidth = 5, double? dashSpace = 3})
const

Properties

color Color?
final
dashSpace double?
final
dashWidth double?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited