FxFieldOptions class

Constructors

FxFieldOptions({String? label, String? hint, String? helperText, String? errorText, Widget? prefix, Widget? prefixIcon, Widget? suffix, Widget? suffixIcon, TextCapitalization textCapitalization = TextCapitalization.none, int maxLines = 1, int? maxLength, FocusNode? focusNode, bool autofocus = false, bool autocorrect = false, bool enableSuggestions = false, bool readOnly = false, bool showCursor = false, bool showErrorText = false, TextInputType keyboardType = TextInputType.text, TextInputAction textInputAction = TextInputAction.next, bool obscureText = false, bool enabled = true, FxLabelBehavior labelBehavior = FxLabelBehavior.auto})
const

Properties

autocorrect bool
final
autofocus bool
final
enabled bool
final
enableSuggestions bool
final
errorText String?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
hint String?
final
keyboardType TextInputType
final
label String?
final
labelBehavior FxLabelBehavior
final
maxLength int?
final
maxLines int
final
obscureText bool
final
prefix Widget?
final
prefixIcon Widget?
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCursor bool
final
showErrorText bool
final
suffix Widget?
final
suffixIcon Widget?
final
textCapitalization TextCapitalization
final
textInputAction TextInputAction
final

Methods

copyWith({String? label, String? hint, String? helperText, String? errorText, Widget? prefix, Widget? prefixIcon, Widget? suffix, Widget? suffixIcon, TextCapitalization? textCapitalization, int? maxLines, int? maxLength, FocusNode? focusNode, bool? autofocus, bool? autocorrect, bool? enableSuggestions, bool? readOnly, bool? showCursor, bool? showErrorText, TextInputType? keyboardType, TextInputAction? textInputAction, bool? obscureText, bool? enabled, FxLabelBehavior? labelBehavior}) FxFieldOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited