FxFormControl class

Constructors

FxFormControl({bool autofocus = false, Widget? prefixIcon, Widget? suffixIcon, String? label, String? hint, FormFieldValidator<String>? validator, TextInputType? keyboardType, TextInputAction? textInputAction, bool isPassword = false, String? initialValue, bool isHidden = false, TextEditingController? controller})
const

Properties

autofocus bool
final
controller TextEditingController?
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
initialValue String?
final
isHidden bool
final
isPassword bool
final
keyboardType TextInputType?
final
label String?
final
prefixIcon Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffixIcon Widget?
final
textInputAction TextInputAction?
final
validator FormFieldValidator<String>?
final
value String?
no setter

Methods

copyWith({TextEditingController? controller, bool? autofocus, Widget? prefixIcon, Widget? suffixIcon, String? label, String? hint, FormFieldValidator<String>? validator, TextInputType? keyboardType, bool? isPassword, TextInputAction? textInputAction, bool? isHidden, String? initialValue}) FxFormControl
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited