FxOverlayListData<T> class

Constructors

FxOverlayListData({String? searchHint = 'Search...', List<T>? items, Stream<List<T>>? itemsAsStream, T? selectedItem, Widget itemBuilder(BuildContext, T, bool isSelected)?, Widget titleBuilder(T)?, Widget subtitleBuilder(T)?, String titleTextBuilder(T)?, String subtitleTextBuilder(T)?, String trailingTextBuilder(T)?, Widget leadingBuilder(T, double size)?, Widget trailingBuilder(T, double size)?, List<T>? onSearch(String? search, List<T> items)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
itemBuilder Widget Function(BuildContext, T, bool isSelected)?
Builder for the item widget
final
items List<T>?
List of items to display
final
itemsAsStream Stream<List<T>>?
Stream of items to display
final
leadingBuilder Widget Function(T, double size)?
Builder for the leading of the item
final
onSearch List<T>? Function(String? search, List<T> items)?
Callback for the search field
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHint String?
Search hint for the search field
final
selectedItem → T?
Selected item
final
subtitleBuilder Widget Function(T)?
Builder for the subtitle of the item
final
subtitleTextBuilder String Function(T)?
Builder for the subtitle text of the item
final
titleBuilder Widget Function(T)?
Builder for the title of the item
final
titleTextBuilder String Function(T)?
Builder for the title text of the item
final
trailingBuilder Widget Function(T, double size)?
Builder for the trailing of the item
final
trailingTextBuilder String Function(T)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited