FxOverlayThemeData class

Constructors

FxOverlayThemeData({EdgeInsetsGeometry? searchPadding, EdgeInsets? margin, ShapeBorder? shape, EdgeInsets? contentPadding, double? horizontalTitleGap, TextStyle? titleStyle, TextAlign titleAlignment = TextAlign.center, FxDottedDividerThemeData? dividerTheme = const FxDottedDividerThemeData(), BoxDecoration modalDecoration = const BoxDecoration(), BoxDecoration dialogDecoration = const BoxDecoration(), BoxDecoration bottomSheetDecoration = const BoxDecoration(), BoxDecoration handleDecoration = const BoxDecoration(), Color barrierColor = Colors.black54, Size handleSize = const Size(64.0, 5.0), double handleMargin = 12.0})
const

Properties

barrierColor Color
final
bottomSheetDecoration BoxDecoration
final
contentPadding EdgeInsets?
final
dialogDecoration BoxDecoration
final
dividerTheme FxDottedDividerThemeData?
final
handleDecoration BoxDecoration
final
handleHeight double
no setter
handleMargin double
final
handleSize Size
final
hashCode int
The hash code for this object.
no setterinherited
horizontalTitleGap double?
final
margin EdgeInsets?
final
modalDecoration BoxDecoration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchPadding EdgeInsetsGeometry?
final
shape ShapeBorder?
final
titleAlignment TextAlign
final
titleStyle TextStyle?
final

Methods

copyWith({EdgeInsets? searchPadding, EdgeInsets? margin, ShapeBorder? shape, TextStyle? titleStyle, EdgeInsets? contentPadding, double? horizontalTitleGap, TextAlign? titleAlignment, BoxDecoration? dialogDecoration, BoxDecoration? modalDecoration, BoxDecoration? bottomSheetDecoration, BoxDecoration? handleDecoration, Color? barrierColor, Size? handleSize, double? handleMargin, FxDottedDividerThemeData? dividerTheme}) FxOverlayThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited