FxOverlayView<T> class
Routes FxOverlayData to a list picker or custom body.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FxOverlayView
- Mixed-in types
Constructors
-
FxOverlayView({Key? key, bool showTitle = true, bool isScrollable = true, required FxOverlayOptions<
T> options, required ScrollController scrollController})
Properties
- canPop → bool
-
Returns true if there is a route to pop.
no setterinherited
- colors → FxColors
-
Returns the colors for the context.
no setterinherited
- colorScheme → ColorScheme
-
Returns the color scheme for the context.
no setterinherited
- componentTheme → FxComponentTheme
-
Returns the component theme for the context.
no setterinherited
- flutterTextTheme → TextTheme
-
Returns the text theme for the context.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkMode → bool
-
Returns true if the theme is dark mode.
no setterinherited
- isDesktop → bool
-
Returns true if the screen is a desktop.
no setterinherited
- isPhone → bool
-
Returns true if the screen is a phone.
no setterinherited
- isScrollable → bool
-
final
- isTablet → bool
-
Returns true if the screen is a tablet.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mediaQuery → MediaQueryData
-
Returns the media query data for the context.
no setterinherited
-
options
→ FxOverlayOptions<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safePadding → EdgeInsets
-
Returns the safe area padding for the context.
no setterinherited
- screenHeight → double
-
Returns the screen height for the context.
no setterinherited
- screenSize → Size
-
Returns the screen size for the context.
no setterinherited
- screenWidth → double
-
Returns the screen width for the context.
no setterinherited
- scrollController → ScrollController
-
final
- shellScope → FxShellScope?
-
Returns the FxShellScope if it exists, otherwise returns null.
Example:
no setterinherited
- showTitle → bool
-
final
- sizes → FxSizes
-
Returns the sizes for the context.
no setterinherited
- theme → ThemeData
-
Returns the theme data for the context.
no setterinherited
- themeData → FxThemeData
-
Returns the theme data for the context.
no setterinherited
- typography → FxTypography
-
Returns the typography for the context.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<
T> ([T? result]) → void -
Pops the current route off the stack.
inherited
-
push(
String route) → void -
Pushes a named route onto the stack.
inherited
-
pushAndClearStack(
String route) → void -
Clears the entire stack and pushes a named route.
inherited
-
pushReplace(
String route) → void -
Replaces the current route with a named route.
inherited
-
setToolkitContext(
BuildContext ctx) → void -
inherited
-
showSnackBar(
SnackBar snackBar) → void -
Shows a snack bar.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toggleTheme(
WidgetRef ref) → void -
Toggles the theme between light and dark mode.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
unfocus(
) → void -
Unfocuses the current focus node.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited