FxPhoneInputViewData class

Annotations

Constructors

FxPhoneInputViewData({required FxPhoneInputConfig config, required FxPhoneInputTheme theme, required List<FxCountry> favoriteCountries, required List<FxCountry> countries, required ValueChanged<String?>? onSaved, required FormFieldValidator<String>? validator, required TextEditingController controller, required ValueChanged<String>? onSubmitted, required FxCountry selectedCountry, required ValueChanged<FxCountry> onCountryChanged})
const

Properties

config FxPhoneInputConfig
final
controller TextEditingController
final
countries List<FxCountry>
final
favoriteCountries List<FxCountry>
final
hashCode int
The hash code for this object.
no setterinherited
isIntegrated bool
no setter
isSplit bool
no setter
isStacked bool
no setter
onCountryChanged ValueChanged<FxCountry>
final
onSaved ValueChanged<String?>?
final
onSubmitted ValueChanged<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCountry → FxCountry
final
theme → FxPhoneInputTheme
final
validator FormFieldValidator<String>?
final

Methods

countryDecoration() InputDecoration
countryLabel() String
countryOptions(Widget countryFlag) FxFieldOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
phoneOptions(Widget prefixIcon) FxFieldOptions
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited