FxPinInputField class

A single digit cell used by FxPinInput.

Wraps a TextFormField with a KeyboardListener to detect backspace on an empty cell, allowing focus to return to the previous cell.

Inheritance

Constructors

FxPinInputField({Key? key, required TextEditingController controller, required FocusNode focusNode, required ValueChanged<String> onChanged, bool obscureText = false, bool enabled = true, bool hasError = false, FxPinInputTheme inputTheme = const FxPinInputTheme(), VoidCallback? onBackspace, VoidCallback? onTap, int pasteLength = 1})
const

Properties

controller TextEditingController
final
enabled bool
final
focusNode FocusNode
final
hasError bool
final
hashCode int
The hash code for this object.
no setterinherited
inputTheme FxPinInputTheme
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
obscureText bool
final
onBackspace VoidCallback?
Called when backspace is pressed on an empty cell.
final
onChanged ValueChanged<String>
final
onTap VoidCallback?
Called when the cell is tapped. Use to redirect focus to the active cell.
final
pasteLength int
Maximum number of characters allowed through onChanged.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FxPinInputField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited