FxPinInputState class
- Inheritance
-
- Object
- State<
FxPinInput> - FxPinInputState
- Mixed-in types
Constructors
Properties
- canPop → bool
-
Returns true if there is a route to pop.
no setterinherited
- colors → FxColors
-
Returns the colors for the context.
no setterinherited
- colorScheme → ColorScheme
-
Returns the color scheme for the context.
no setterinherited
- componentTheme → FxComponentTheme
-
Returns the component theme for the context.
no setterinherited
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- defaultPinTheme → PinTheme
-
no setter
- flutterTextTheme → TextTheme
-
Returns the text theme for the context.
no setterinherited
- focusNode ↔ FocusNode
-
latefinal
-
formKey
↔ GlobalKey<
FormState> -
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkMode → bool
-
Returns true if the theme is dark mode.
no setterinherited
- isDesktop → bool
-
Returns true if the screen is a desktop.
no setterinherited
- isPhone → bool
-
Returns true if the screen is a phone.
no setterinherited
- isTablet → bool
-
Returns true if the screen is a tablet.
no setterinherited
- mediaQuery → MediaQueryData
-
Returns the media query data for the context.
no setterinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- pinController ↔ TextEditingController
-
latefinal
- pinTheme → FxPinInputTheme
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safePadding → EdgeInsets
-
Returns the safe area padding for the context.
no setterinherited
- screenHeight → double
-
Returns the screen height for the context.
no setterinherited
- screenSize → Size
-
Returns the screen size for the context.
no setterinherited
- screenWidth → double
-
Returns the screen width for the context.
no setterinherited
- shellScope → FxShellScope?
-
Returns the FxShellScope if it exists, otherwise returns null.
Example:
no setterinherited
- sizes → FxSizes
-
Returns the sizes for the context.
no setterinherited
- theme → ThemeData
-
Returns the theme data for the context.
no setterinherited
- themeData → FxThemeData
-
Returns the theme data for the context.
no setterinherited
- typography → FxTypography
-
Returns the typography for the context.
no setterinherited
- widget → FxPinInput
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant FxPinInput oldWidget) → void -
Called whenever the widget configuration changes.
override
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<
T> ([T? result]) → void -
Pops the current route off the stack.
inherited
-
push(
String route) → void -
Pushes a named route onto the stack.
inherited
-
pushAndClearStack(
String route) → void -
Clears the entire stack and pushes a named route.
inherited
-
pushReplace(
String route) → void -
Replaces the current route with a named route.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
setToolkitContext(
BuildContext ctx) → void -
inherited
-
showSnackBar(
SnackBar snackBar) → void -
Shows a snack bar.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toggleTheme(
WidgetRef ref) → void -
Toggles the theme between light and dark mode.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
unfocus(
) → void -
Unfocuses the current focus node.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited