FxPinInputTheme class

Constructors

FxPinInputTheme({EdgeInsetsGeometry? padding, Color? borderColor, Color? backgroundColor, Color? errorBorderColor, Color? focusBorderColor, TextStyle? textStyle, InputBorder border = const OutlineInputBorder(), double? spacing})
const
FxPinInputTheme.fromTheme(ThemeData theme)
factory

Properties

backgroundColor Color?
final
border InputBorder
final
borderColor Color?
final
errorBorderColor Color?
final
focusBorderColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double?
final
textStyle TextStyle?
final

Methods

copyWith({double? spacing, Color? borderColor, Color? backgroundColor, Color? errorBorderColor, Color? focusBorderColor, TextStyle? textStyle, InputBorder? border, EdgeInsetsGeometry? padding}) FxPinInputTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited