FxRowTileStyle class

Inheritance
Annotations

Constructors

FxRowTileStyle({EdgeInsetsGeometry padding = EdgeInsets.zero, FxTileState<double?>? iconSize, FxTileState<TextStyle>? textStyle, FxTileState<TextStyle>? subtitleStyle, FxTileState<Color>? iconColor, FxTileState<Color>? backgroundColor, Duration duration = const Duration(milliseconds: 300), Duration? reverseDuration, Curve switchInCurve = Curves.linear, Curve switchOutCurve = Curves.linear, Widget transitionBuilder(Widget, Animation<double>) = AnimatedSwitcher.defaultTransitionBuilder, Widget layoutBuilder(Widget?, List<Widget>) = AnimatedSwitcher.defaultLayoutBuilder, double spacing = 0, MainAxisSize mainAxisSize = MainAxisSize.max, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start})
const
FxRowTileStyle.fromTileStyle(FxTileStyle style)
factory

Properties

backgroundColor FxTileState<Color>?
finalinherited
crossAxisAlignment CrossAxisAlignment
final
duration Duration
finalinherited
hashCode int
The hash code for this object.
no setterinherited
iconColor FxTileState<Color>?
finalinherited
iconSize FxTileState<double?>?
finalinherited
layoutBuilder Widget Function(Widget?, List<Widget>)
finalinherited
mainAxisAlignment MainAxisAlignment
final
mainAxisSize MainAxisSize
final
padding EdgeInsetsGeometry
finalinherited
reverseDuration Duration?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
final
subtitleStyle FxTileState<TextStyle>?
finalinherited
switchInCurve Curve
finalinherited
switchOutCurve Curve
finalinherited
textStyle FxTileState<TextStyle>?
finalinherited
transitionBuilder Widget Function(Widget, Animation<double>)
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited