resizeToAvoidBottomInset property
The resize to avoid bottom inset of the scaffold. Default is true.
Implementation
final bool resizeToAvoidBottomInset;
The resize to avoid bottom inset of the scaffold. Default is true.
final bool resizeToAvoidBottomInset;