FxScaffoldStyle class
Constructors
- FxScaffoldStyle({bool primary = true, FxSafeAreaInsets? safeArea = const FxSafeAreaInsets(), bool extendBody = false, bool extendBodyBehindAppBar = false, DragStartBehavior drawerDragStartBehavior = DragStartBehavior.start, bool drawerEnableOpenDragGesture = true, bool endDrawerEnableOpenDragGesture = true, EdgeInsetsGeometry? padding, String? restorationId, Color? backgroundColor, Color? drawerScrimColor, double? drawerEdgeDragWidth, SystemUiOverlayStyle? systemUiOverlayStyle, bool? resizeToAvoidBottomInset})
-
const
Properties
- backgroundColor → Color?
-
final
- drawerDragStartBehavior → DragStartBehavior
-
final
- drawerEdgeDragWidth → double?
-
final
- drawerEnableOpenDragGesture → bool
-
final
- drawerScrimColor → Color?
-
final
- endDrawerEnableOpenDragGesture → bool
-
final
- extendBody → bool
-
final
- extendBodyBehindAppBar → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsetsGeometry?
-
final
- primary → bool
-
final
- resizeToAvoidBottomInset → bool?
-
final
- restorationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safeArea → FxSafeAreaInsets?
-
final
- systemUiOverlayStyle → SystemUiOverlayStyle?
-
final
Methods
-
copyWith(
{bool? primary, bool? extendBody, FxSafeAreaInsets? safeArea, EdgeInsetsGeometry? padding, SystemUiOverlayStyle? systemUiOverlayStyle}) → FxScaffoldStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited