FxScrollableForm class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FxScrollableForm
- Mixed-in types
Constructors
-
FxScrollableForm({Key? key, required List<
Widget> children, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.onDrag, BoxConstraints? constraints, EdgeInsets? padding, double? spacing, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.stretch, Widget? header, FxSafeAreaInsets safeArea = const FxSafeAreaInsets()})
Properties
- canPop → bool
-
Returns true if there is a route to pop.
no setterinherited
-
children
→ List<
Widget> -
The children widgets of the scrollable form.
final
- colors → FxColors
-
Returns the colors for the context.
no setterinherited
- colorScheme → ColorScheme
-
Returns the color scheme for the context.
no setterinherited
- componentTheme → FxComponentTheme
-
Returns the component theme for the context.
no setterinherited
- constraints → BoxConstraints?
-
The constraints of the scrollable form. Default is null.
final
- crossAxisAlignment → CrossAxisAlignment
-
The cross axis alignment of the children. Default is CrossAxisAlignment.stretch.
final
- flutterTextTheme → TextTheme
-
Returns the text theme for the context.
no setterinherited
-
The footer widget Default is null.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
The header widget Default is null.
final
- isDarkMode → bool
-
Returns true if the theme is dark mode.
no setterinherited
- isDesktop → bool
-
Returns true if the screen is a desktop.
no setterinherited
- isPhone → bool
-
Returns true if the screen is a phone.
no setterinherited
- isTablet → bool
-
Returns true if the screen is a tablet.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardDismissBehavior → ScrollViewKeyboardDismissBehavior
-
The keyboard dismiss behavior of the scrollable form. Default is ScrollViewKeyboardDismissBehavior.onDrag.
final
- mainAxisAlignment → MainAxisAlignment
-
The main axis alignment of the children. Default is MainAxisAlignment.center.
final
- mediaQuery → MediaQueryData
-
Returns the media query data for the context.
no setterinherited
- padding → EdgeInsets?
-
The padding of the scrollable form. Default is null.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safeArea → FxSafeAreaInsets
-
The safe area of the scrollable form. Default is null.
final
- safePadding → EdgeInsets
-
Returns the safe area padding for the context.
no setterinherited
- screenHeight → double
-
Returns the screen height for the context.
no setterinherited
- screenSize → Size
-
Returns the screen size for the context.
no setterinherited
- screenWidth → double
-
Returns the screen width for the context.
no setterinherited
- shellScope → FxShellScope?
-
Returns the FxShellScope if it exists, otherwise returns null.
Example:
no setterinherited
- sizes → FxSizes
-
Returns the sizes for the context.
no setterinherited
- spacing → double?
-
The spacing between the children widgets Default is
sizes.md.final - theme → ThemeData
-
Returns the theme data for the context.
no setterinherited
- themeData → FxThemeData
-
Returns the theme data for the context.
no setterinherited
- typography → FxTypography
-
Returns the typography for the context.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<
T> ([T? result]) → void -
Pops the current route off the stack.
inherited
-
push(
String route) → void -
Pushes a named route onto the stack.
inherited
-
pushAndClearStack(
String route) → void -
Clears the entire stack and pushes a named route.
inherited
-
pushReplace(
String route) → void -
Replaces the current route with a named route.
inherited
-
setToolkitContext(
BuildContext ctx) → void -
inherited
-
showSnackBar(
SnackBar snackBar) → void -
Shows a snack bar.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toggleTheme(
WidgetRef ref) → void -
Toggles the theme between light and dark mode.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
unfocus(
) → void -
Unfocuses the current focus node.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited