FxSelectField<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FxSelectField
Constructors
-
FxSelectField({Key? key, T? selectedValue, List<
T> ? selectedValues, required void onChanged(T value, List<T> ? values), List<T> ? onSearch(String? search, List<T> items)?, required FxSelectFieldData<T> data, FxOverlayStyle overlayStyle = FxOverlayStyle.bottomSheet, String? label, String? hint, String? errorText, bool enabled = true, Widget? prefixIcon, Widget? suffixIcon, InputDecoration? decoration}) -
const
Properties
-
data
→ FxSelectFieldData<
T> -
final
- decoration → InputDecoration?
-
final
- enabled → bool
-
final
- errorText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
-
onChanged
→ void Function(T value, List<
T> ? values) -
final
-
onSearch
→ List<
T> ? Function(String? search, List<T> items)? -
final
- overlayStyle → FxOverlayStyle
-
final
- prefixIcon → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedValue → T?
-
final
-
selectedValues
→ List<
T> ? -
final
- suffixIcon → Widget?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FxSelectField< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited