FxSelectFieldData<T> class

Constructors

FxSelectFieldData({List<T>? items, Stream<List<T>>? itemsAsStream, String labelBuilder(T)?, Widget itemBuilder(BuildContext, T, bool isSelected)?, Widget selectedBuilder(T)?, String searchHint = 'Search...', List<T> onSearch(String query, List<T> items)?, bool multiSelect = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
itemBuilder Widget Function(BuildContext, T, bool isSelected)?
Builder for the custom item widget (overrides labelBuilder in list)
final
items List<T>?
List of items to display
final
itemsAsStream Stream<List<T>>?
Stream of items to display
final
labelBuilder String Function(T)?
Builder for the label of each item in the list
final
multiSelect bool
Allow multiple selection
final
onSearch List<T> Function(String query, List<T> items)?
search callback that returns the filtered items
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHint String
Search hint text
final
selectedBuilder Widget Function(T)?
Builder for the selected value in the field trigger
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited