dockPanes property

List<FxPane>? dockPanes
final

Panes for the dock. FxSite.dock and FxSite.spacer FxSite.spacer is used as a vertical gap in a dock. It is used to separate the panes in a dock.

Implementation

final List<FxPane>? dockPanes;