FxShellCtrl class

Annotations
  • @Riverpod.new(keepAlive: true)

Constructors

FxShellCtrl()

Properties

canPop bool
no setter
hashCode int
The hash code for this object.
no setterinherited
ref → Ref
The Ref associated with this notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state FxShellState
The value currently exposed by this notifier.
getter/setter pairinherited
stateOrNull FxShellState?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() FxShellState
goToPane(FxPane pane) → void
listenSelf(void listener(FxShellState? previous, FxShellState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop() bool
runBuild() → void
Executes Notifier.build.
inherited
syncFromWidget({required List<FxPane> dockPanes, List<FxPane> drawerPanes = const [], List<FxPane> endDrawerPanes = const [], required String initialPaneKey}) → void
toString() String
A string representation of this object.
inherited
updateShouldNotify(FxShellState previous, FxShellState next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited