FxShellState class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
- canPopShell → bool
-
no setter
-
copyWith
→ $FxShellStateCopyWith<
FxShellState> -
Create a copy of FxShellState
with the given fields replaced by the non-null parameter values.
no setterinherited
- currentPane → FxPane?
-
no setterinherited
- currentPaneKey → String?
-
no setter
-
dockPanes
→ List<
FxPane> -
no setterinherited
-
drawerPanes
→ List<
FxPane> -
no setterinherited
-
endDrawerPanes
→ List<
FxPane> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
history
→ List<
String> -
no setterinherited
- isForward → bool
-
Whether the the changing pane is pop forward or back.
no setter
- previousPaneKey → String?
-
no setter
-
registry
→ List<
FxPane> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hasSite(
FxSite site) → bool -
map<
TResult extends Object?> (TResult $default(_FxShellState value)) → TResult -
Available on FxShellState, provided by the FxShellStatePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_FxShellState value)?) → TResult? -
Available on FxShellState, provided by the FxShellStatePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_FxShellState value)?, {required TResult orElse()}) → TResult -
Available on FxShellState, provided by the FxShellStatePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(FxPane? currentPane, List< FxPane> dockPanes, List<FxPane> drawerPanes, List<FxPane> endDrawerPanes, List<FxPane> registry, List<String> history)?, {required TResult orElse()}) → TResult -
Available on FxShellState, provided by the FxShellStatePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paneByKey(
String key) → FxPane? -
panesFor(
FxSite site) → List< FxPane> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(FxPane? currentPane, List< FxPane> dockPanes, List<FxPane> drawerPanes, List<FxPane> endDrawerPanes, List<FxPane> registry, List<String> history)) → TResult -
Available on FxShellState, provided by the FxShellStatePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(FxPane? currentPane, List< FxPane> dockPanes, List<FxPane> drawerPanes, List<FxPane> endDrawerPanes, List<FxPane> registry, List<String> history)?) → TResult? -
Available on FxShellState, provided by the FxShellStatePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited