isForward property
bool
get
isForward
Whether the the changing pane is pop forward or back.
Implementation
bool get isForward => true;
Whether the the changing pane is pop forward or back.
bool get isForward => true;