FxShellStyle class

Available extensions
Annotations
  • @CopyWith.new()

Constructors

FxShellStyle({FxDockStyle dockStyle = const FxDockStyle(), FxAppBarStyle appBarStyle = const FxAppBarStyle(), FxDrawerStyle drawerStyle = const FxDrawerStyle(), FxScaffoldStyle scaffoldStyle = const FxScaffoldStyle(), FxDrawerStyle endDrawerStyle = const FxDrawerStyle(), Duration animationDuration = const Duration(milliseconds: 300), FloatingActionButtonLocation floatingActionButtonLocation = FloatingActionButtonLocation.centerDocked})
const

Properties

animationDuration Duration
Animation duration for the body.
final
appBarStyle FxAppBarStyle
Shared app bar styling when FxPane.showAppBar is true.
final
copyWith FxShellStyleCopyWithFn

Available on FxShellStyle, provided by the FxShellStyleCopyWith extension

no setter
dockStyle FxDockStyle
Bottom dock styling.
final
drawerStyle FxDrawerStyle
Start drawer styling.
final
endDrawerStyle FxDrawerStyle
End drawer styling.
final
floatingActionButtonLocation FloatingActionButtonLocation
Location of the floating action button.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaffoldStyle FxScaffoldStyle
Outer FxScaffold options (padding is forced to zero on the body).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited