Snackbar utility with themed variants.
Usage:
FxSnackbar.show(context, message: 'Saved!', type: FxSnackbarType.success);
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
BuildContext context, {required String message, FxSnackbarType type = FxSnackbarType.info, Duration duration = const Duration(seconds: 3), String? actionLabel, VoidCallback? onAction}) → void