FxStateData class

Available extensions
Annotations
  • @CopyWith.new()

Constructors

FxStateData({Widget icon = const Icon(CupertinoIcons.info), required String title, required String description, FxStateStyle? style, String? actionLabel})
const

Properties

actionLabel String?
final
copyWith FxStateDataCopyWithFn

Available on FxStateData, provided by the FxStateDataCopyWith extension

no setter
description String
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style FxStateStyle?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited