FxStateStyle class

Constructors

FxStateStyle({Color? iconColor, double? iconSize, TextStyle? titleStyle, TextStyle? descriptionStyle, Color? actionForegroundColor, Color? actionBorderColor})
const

Properties

actionBorderColor Color?
final
actionForegroundColor Color?
final
descriptionStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color?
final
iconSize double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited