FxText class
A rich text widget that supports inline tappable spans using a markdown-inspired bracket syntax.
Wrap any word or phrase in square brackets to make it tappable:
FxText(
'By continuing you agree to our [Terms] and [Privacy Policy].',
onTap: (index, text) {
if (index == 0) openTerms();
if (index == 1) openPrivacy();
},
)
Use FxTextStyle to control appearance. Link color defaults to ColorScheme.primary when not explicitly set.
- Inheritance
Constructors
- FxText(String text, {Key? key, EdgeInsets padding = EdgeInsets.zero, FxTextStyle style = const FxTextStyle(), TextAlign textAlign = TextAlign.start, FxTextOnLinkTap? onTap})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → FxTextOnLinkTap?
-
Called when a
[bracketed]span is tapped.final - padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → FxTextStyle
-
final
- text → String
-
final
- textAlign → TextAlign
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FxText> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited