FxTileView<T extends FxTile> class
Vertical list or horizontal row of FxTiles.
In row mode, Expanded is applied only in _buildRow when
FxTile.isExpanded is true. Custom FxTileBuilders must not return
Expanded.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FxTileView
- Annotations
Constructors
-
FxTileView({Key? key, Widget? header, required List<
T> tiles, required FxTileStyle tileStyle, String? activeKey, FxTileBuilder<T> ? tileBuilder, FxTileTap<T> ? onTilePressed, IndexedWidgetBuilder? separatorBuilder, EdgeInsetsGeometry padding = EdgeInsets.zero, bool primary = false, ScrollPhysics physics = const BouncingScrollPhysics(), bool shrinkWrap = false}) -
const
-
FxTileView.row({Key? key, required List<
T> tiles, required FxRowTileStyle style, String? activeKey, FxTileBuilder<T> ? tileBuilder, FxTileTap<T> ? onTilePressed, double spacing = 0, MainAxisSize mainAxisSize = MainAxisSize.max, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start}) -
const
Properties
- activeKey → String?
-
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- end → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isListView → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
final
- mainAxisSize → MainAxisSize
-
final
-
onTilePressed
→ FxTileTap<
T> ? -
final
- padding → EdgeInsetsGeometry
-
final
- physics → ScrollPhysics
-
final
- primary → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separatorBuilder → IndexedWidgetBuilder?
-
final
- shrinkWrap → bool
-
final
- spacing → double
-
final
- start → Widget?
-
final
-
tileBuilder
→ FxTileBuilder<
T> ? -
final
-
tiles
→ List<
T> -
final
- tileStyle → FxTileStyle
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited