FxUiContext class
- Mixed-in types
Constructors
- FxUiContext.of(BuildContext context)
- Constructor for the FxUiContext. Example:
Properties
- canPop → bool
-
Returns true if there is a route to pop.
no setterinherited
- colors → FxColors
-
Returns the colors for the context.
no setterinherited
- colorScheme → ColorScheme
-
Returns the color scheme for the context.
no setterinherited
- componentTheme → FxComponentTheme
-
Returns the component theme for the context.
no setterinherited
- flutterTextTheme → TextTheme
-
Returns the text theme for the context.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkMode → bool
-
Returns true if the theme is dark mode.
no setterinherited
- isDesktop → bool
-
Returns true if the screen is a desktop.
no setterinherited
- isPhone → bool
-
Returns true if the screen is a phone.
no setterinherited
- isTablet → bool
-
Returns true if the screen is a tablet.
no setterinherited
- mediaQuery → MediaQueryData
-
Returns the media query data for the context.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safePadding → EdgeInsets
-
Returns the safe area padding for the context.
no setterinherited
- screenHeight → double
-
Returns the screen height for the context.
no setterinherited
- screenSize → Size
-
Returns the screen size for the context.
no setterinherited
- screenWidth → double
-
Returns the screen width for the context.
no setterinherited
- shellScope → FxShellScope?
-
Returns the FxShellScope if it exists, otherwise returns null.
Example:
no setterinherited
- sizes → FxSizes
-
Returns the sizes for the context.
no setterinherited
- theme → ThemeData
-
Returns the theme data for the context.
no setterinherited
- themeData → FxThemeData
-
Returns the theme data for the context.
no setterinherited
- typography → FxTypography
-
Returns the typography for the context.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<
T> ([T? result]) → void -
Pops the current route off the stack.
inherited
-
push(
String route) → void -
Pushes a named route onto the stack.
inherited
-
pushAndClearStack(
String route) → void -
Clears the entire stack and pushes a named route.
inherited
-
pushReplace(
String route) → void -
Replaces the current route with a named route.
inherited
-
setToolkitContext(
BuildContext ctx) → void -
inherited
-
showSnackBar(
SnackBar snackBar) → void -
Shows a snack bar.
inherited
-
toggleTheme(
WidgetRef ref) → void -
Toggles the theme between light and dark mode.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unfocus(
) → void -
Unfocuses the current focus node.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited