NumberFormatter class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compact(num value) String
e.g. 1200 → "1.2K", 1500000 → "1.5M"
decimal(num value, {int decimalPlaces = 2}) String
e.g. 1234.5 → "1,234.50"
formatBytes(int bytes) String
percent(num value, {int decimalPlaces = 0}) String
e.g. 0.75 → "75%"