PhoneParseResult class

Parsed phone data from libphonenumber (parse map).

Constructors

PhoneParseResult({required String fullNumber, required String formattedNumber, String? national, String? type})
const

Properties

formattedNumber String
Same digits as fullNumber, spaced for display (e.g. +1 415 555 2671).
final
fullNumber String
Complete number with country code (e.g. +14155552671). Use this for APIs, SMS, and storage.
final
hashCode int
The hash code for this object.
no setterinherited
national String?
National format when available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Libphonenumber type label when available (e.g. mobile).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited