AuthService class
Handles all shared /auth/* and /users/* API calls.
- Inheritance
-
- Object
- AppService
- AuthService
Constructors
Properties
- dio → Dio
-
finalinherited
- endpoints → ApiEndpoints
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
changePassword(
{required String currentPassword, required String newPassword}) → Future< void> -
confirmAccountDeletion(
Map< String, dynamic> body) → Future<void> -
getMe(
) → Future< AuthUser> -
getSessions(
) → Future< List< AuthSession> > -
logout(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
String refreshToken) → Future< AuthTokens> -
register(
Map< String, dynamic> body) → Future<AuthTokens> -
requestAccountDeletion(
) → Future< Map< String, dynamic> > -
revokeSession(
String sessionId) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited