AuthState class abstract

Immutable snapshot of the current auth session.

Available extensions
Annotations
  • @freezed

Constructors

AuthState({@Default.new(AuthStatus.unauthenticated) AuthStatus status, AuthUser? user, String? error})
const
factory

Properties

copyWith → $AuthStateCopyWith<AuthState>
Create a copy of AuthState with the given fields replaced by the non-null parameter values.
no setterinherited
error String?
no setterinherited
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isAuthenticated bool
no setter
isLoading bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AuthStatus
no setterinherited
user AuthUser?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AuthState value)) → TResult

Available on AuthState, provided by the AuthStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AuthState value)?) → TResult?

Available on AuthState, provided by the AuthStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AuthState value)?, {required TResult orElse()}) → TResult

Available on AuthState, provided by the AuthStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(AuthStatus status, AuthUser? user, String? error)?, {required TResult orElse()}) → TResult

Available on AuthState, provided by the AuthStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(AuthStatus status, AuthUser? user, String? error)) → TResult

Available on AuthState, provided by the AuthStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(AuthStatus status, AuthUser? user, String? error)?) → TResult?

Available on AuthState, provided by the AuthStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited