AuthStepLayout class
Visual layout for an auth step shell.
- Annotations
Constructors
- AuthStepLayout({String? title, String? subtitle, TextStyle? titleStyle, TextStyle? subtitleStyle, String actionLabel = 'Continue', EdgeInsets? contentPadding, double? contentSpacing, double? headerSpacing, TextAlign textAlign = TextAlign.center, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.stretch, void titleOnTap(int position, String text)?, void subtitleOnTap(int position, String text)?})
-
const
Properties
- actionLabel → String
-
final
- contentPadding → EdgeInsets?
-
final
- contentSpacing → double?
-
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasHeaderContent → bool
-
no setter
- headerSpacing → double?
-
final
- mainAxisAlignment → MainAxisAlignment
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
final
- subtitleOnTap → void Function(int position, String text)?
-
final
- subtitleStyle → TextStyle?
-
final
- textAlign → TextAlign
-
final
- title → String?
-
final
- titleOnTap → void Function(int position, String text)?
-
final
- titleStyle → TextStyle?
-
final
Methods
-
copyWith(
{String? title, String? subtitle}) → AuthStepLayout -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited