AuthStorage class
Persists the refresh token and user profile to secure storage.
The access token is NEVER persisted — it lives in TokenManager in memory,
obtained fresh via a token refresh on the first protected request.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → Future< void> -
getRefreshToken(
) → Future< String?> -
getUser(
) → Future< User?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveRefreshToken(
String token) → Future< void> -
saveUser(
User user) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited