EmailRegisterRequest class abstract
Request body for AuthMethod.email registration.
- Available extensions
- Annotations
-
- @freezed
Constructors
- EmailRegisterRequest({required String firstName, required String lastName, required String email, required String password, String? phone, String? countryCode})
-
constfactory
-
EmailRegisterRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $EmailRegisterRequestCopyWith<
EmailRegisterRequest> -
Create a copy of EmailRegisterRequest
with the given fields replaced by the non-null parameter values.
no setterinherited
- countryCode → String?
-
no setterinherited
- email → String
-
no setterinherited
- firstName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String
-
no setterinherited
- password → String
-
no setterinherited
- phone → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EmailRegisterRequest value)) → TResult -
Available on EmailRegisterRequest, provided by the EmailRegisterRequestPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EmailRegisterRequest value)?) → TResult? -
Available on EmailRegisterRequest, provided by the EmailRegisterRequestPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EmailRegisterRequest value)?, {required TResult orElse()}) → TResult -
Available on EmailRegisterRequest, provided by the EmailRegisterRequestPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String firstName, String lastName, String email, String password, String? phone, String? countryCode)?, {required TResult orElse()}) → TResult -
Available on EmailRegisterRequest, provided by the EmailRegisterRequestPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EmailRegisterRequest to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String firstName, String lastName, String email, String password, String? phone, String? countryCode)) → TResult -
Available on EmailRegisterRequest, provided by the EmailRegisterRequestPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String firstName, String lastName, String email, String password, String? phone, String? countryCode)?) → TResult? -
Available on EmailRegisterRequest, provided by the EmailRegisterRequestPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited