ForgotPasswordFlowController class
Manages the 3-step forgot password flow:
- ForgotPasswordStep.enterEmail — user submits their email
- ForgotPasswordStep.verifyPin — user enters the PIN sent to their email
- ForgotPasswordStep.newPassword — user sets a new password
Delegates all API calls to authControllerProvider.
- Annotations
-
- @riverpod
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
The
Refassociated with this notifier.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ ForgotPasswordFlowState
-
The value currently exposed by this notifier.
getter/setter pairinherited
- stateOrNull → ForgotPasswordFlowState?
-
The value currently exposed by this
Notifier.no setterinherited
Methods
-
build(
) → ForgotPasswordFlowState -
goBack(
) → void - Navigate back one step.
-
listenSelf(
void listener(ForgotPasswordFlowState? previous, ForgotPasswordFlowState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetPassword(
String newPassword) → Future< bool> -
Step 3: Reset the password using the
newPasswordand storedresetToken. -
runBuild(
) → void -
Executes
Notifier.build.inherited -
sendResetPin(
String email) → Future< void> -
Step 1: Send reset PIN to
email. Advances to ForgotPasswordStep.verifyPin on success. -
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
ForgotPasswordFlowState previous, ForgotPasswordFlowState next) → bool -
A method invoked when the state exposed by this
Notifierchanges. It compares the previous and new value, and return whether listeners should be notified.inherited -
verifyPin(
String pin) → Future< void> -
Step 2: Verify the
pinsent to the user's email. On success, storesresetTokenand advances to ForgotPasswordStep.newPassword.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited