FxForgotPasswordData class
Configuration for FxForgotPasswordWidget.
Constructors
- FxForgotPasswordData({String enterEmailTitle = 'Forgot your password?', String enterEmailSubtitle = "Enter your email and we'll send you a reset code", String enterEmailButtonLabel = 'Send reset code', String verifyPinTitle = 'Check your email', String verifyPinSubtitle = 'Enter the code sent to {{email}}', String verifyPinButtonLabel = 'Verify code', String newPasswordTitle = 'Set new password', String newPasswordSubtitle = 'Choose a strong password for your account', String newPasswordButtonLabel = 'Reset password', int pinLength = 6, int resendCooldownSeconds = 60, String resendPrefixText = "Didn't receive a code?", String resendActionText = 'Resend', String resendCountdownPrefixText = 'Resend in', String invalidPinMessage = 'Invalid or expired code, please try again'})
-
const
Properties
- enterEmailButtonLabel → String
-
final
- enterEmailSubtitle → String
-
final
- enterEmailTitle → String
-
Step 1 — Enter email
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidPinMessage → String
-
final
- newPasswordButtonLabel → String
-
final
- newPasswordSubtitle → String
-
final
- newPasswordTitle → String
-
Step 3 — New password
final
- pinLength → int
-
final
- resendActionText → String
-
final
- resendCooldownSeconds → int
-
final
- resendCountdownPrefixText → String
-
final
- resendPrefixText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifyPinButtonLabel → String
-
final
- verifyPinSubtitle → String
-
final
- verifyPinTitle → String
-
Step 2 — Verify PIN
Use {{email}} as a placeholder for the user's email address.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited