FxPhoneAuthTheme class
Constructors
- FxPhoneAuthTheme({Widget phoneEntryBuilder(BuildContext context)?, Widget otpVerificationBuilder(BuildContext context)?, Widget userDetailsBuilder(BuildContext context)?, bool showInputLabel = false, PhoneEntryConfig phoneEntryConfig = const PhoneEntryConfig(), OtpVerificationConfig otpVerificationConfig = const OtpVerificationConfig(), UserDetailsConfig userDetailsConfig = const UserDetailsConfig()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- otpVerificationBuilder → Widget Function(BuildContext context)?
-
final
- otpVerificationConfig → OtpVerificationConfig
-
final
- phoneEntryBuilder → Widget Function(BuildContext context)?
-
final
- phoneEntryConfig → PhoneEntryConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showInputLabel → bool
-
final
- userDetailsBuilder → Widget Function(BuildContext context)?
-
final
- userDetailsConfig → UserDetailsConfig
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited