OtpVerificationConfig class
Verify phone (OTP)
Constructors
- OtpVerificationConfig({int otpLength = 6, String title = 'Verify your number', String subtitle = 'Enter the code sent to {{phone}}', String buttonLabel = 'Verify', String changeNumberLabel = 'Change number', int resendCooldownSeconds = 60, String resendPrefixText = "Didn't receive a code?", String resendActionText = 'Resend', String resendCountdownPrefixText = 'Resend in', String invalidCodeMessage = 'Invalid code, please try again', String expiredCodeMessage = 'Code expired, please request a new one', Widget keyboardBuilder(TextEditingController phoneController)?})
-
const
Properties
-
The button label for the verify button.
final
- changeNumberLabel → String
-
The label for the change number button.
final
- expiredCodeMessage → String
-
The message text for the expired code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidCodeMessage → String
-
The message text for the invalid code.
final
- keyboardBuilder → Widget Function(TextEditingController phoneController)?
-
The keyboard builder for the otp verification screen.
final
- otpLength → int
-
The length of the otp code.
final
- resendActionText → String
-
The action text for the resend code button.
final
- resendCooldownSeconds → int
-
The cooldown seconds for the resend code button.
final
- resendCountdownPrefixText → String
-
The prefix text for the resend countdown.
final
- resendPrefixText → String
-
The prefix text for the resend code button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String
-
The subtitle text with {{phone}} placeholder for the phone number.
Example: 'Enter the code sent to {{phone}}'
final
- title → String
-
The title text for the otp verification screen.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited