PhoneAuthFlowState class abstract

Available extensions
Annotations
  • @freezed

Constructors

PhoneAuthFlowState({String? phone, @Default.new(FxPhoneAuthStep.enterPhone) FxPhoneAuthStep step, OtpData? otpData, PhoneLookupResult? lookupResult})
const
factory

Properties

copyWith → $PhoneAuthFlowStateCopyWith<PhoneAuthFlowState>
Create a copy of PhoneAuthFlowState with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
lookupResult PhoneLookupResult?
no setterinherited
otpData OtpData?
no setterinherited
phone String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step FxPhoneAuthStep
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PhoneAuthFlowState value)) → TResult

Available on PhoneAuthFlowState, provided by the PhoneAuthFlowStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PhoneAuthFlowState value)?) → TResult?

Available on PhoneAuthFlowState, provided by the PhoneAuthFlowStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PhoneAuthFlowState value)?, {required TResult orElse()}) → TResult

Available on PhoneAuthFlowState, provided by the PhoneAuthFlowStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? phone, FxPhoneAuthStep step, OtpData? otpData, PhoneLookupResult? lookupResult)?, {required TResult orElse()}) → TResult

Available on PhoneAuthFlowState, provided by the PhoneAuthFlowStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? phone, FxPhoneAuthStep step, OtpData? otpData, PhoneLookupResult? lookupResult)) → TResult

Available on PhoneAuthFlowState, provided by the PhoneAuthFlowStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? phone, FxPhoneAuthStep step, OtpData? otpData, PhoneLookupResult? lookupResult)?) → TResult?

Available on PhoneAuthFlowState, provided by the PhoneAuthFlowStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited