PhoneAuthService class

Handles all OTP-specific API calls for the phone auth flow.

Inheritance

Constructors

PhoneAuthService(ServiceContext ctx)

Properties

dio → Dio
finalinherited
endpoints ApiEndpoints
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loginWithToken(String phoneGrantToken) Future<AuthTokens>
Login step for existing users after OTP verification.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resendOtp(String sessionToken) Future<OtpData>
sendOtp(String phone) Future<OtpData>
toString() String
A string representation of this object.
inherited
verifyOtp({required String verificationId, required String code}) Future<PhoneLookupResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited