PhoneEntryConfig class
Phone entry
Constructors
-
PhoneEntryConfig({String? title = 'Enter your phone number', String? subtitle = "We'll send you a verification code", FxFlagShape flagShape = FxFlagShape.circle, double flagSize = 28, String buttonLabel = 'Send code', Widget keyboardBuilder(TextEditingController phoneController)?, Widget? header, EdgeInsets? padding, double? spacing, List<
Widget> otherWidgets = const [], MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.stretch}) -
const
Properties
-
The button label for the send code button.
final
- crossAxisAlignment → CrossAxisAlignment
-
The cross axis alignment for the phone entry screen.
final
- flagShape → FxFlagShape
-
The flag shape for the phone entry screen.
final
- flagSize → double
-
The flag size for the phone entry screen.
final
-
The footer widget for the phone entry screen.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
The header widget for the phone entry screen.
final
- keyboardBuilder → Widget Function(TextEditingController phoneController)?
-
The keyboard builder for the phone entry screen.
final
- mainAxisAlignment → MainAxisAlignment
-
The main axis alignment for the phone entry screen.
final
-
otherWidgets
→ List<
Widget> -
The other widgets for the phone entry screen.
final
- padding → EdgeInsets?
-
The padding for the phone entry screen.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double?
-
The spacing for the phone entry screen.
final
- subtitle → String?
-
The subtitle text for the phone entry screen.
final
- title → String?
-
The title text for the phone entry screen.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited