PhoneEntryConfig class

Phone entry

Constructors

PhoneEntryConfig({String title = 'Enter your phone number', String subtitle = "We'll send you a verification code", FxFlagShape flagShape = FxFlagShape.circle, double flagSize = 28, String buttonLabel = 'Send code', Widget keyboardBuilder(TextEditingController phoneController)?})
const

Properties

buttonLabel String
The button label for the send code button.
final
flagShape FxFlagShape
The flag shape for the phone entry screen.
final
flagSize double
The flag size for the phone entry screen.
final
hashCode int
The hash code for this object.
no setterinherited
keyboardBuilder Widget Function(TextEditingController phoneController)?
The keyboard builder for the phone entry screen.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String
The subtitle text for the phone entry screen.
final
title String
The title text for the phone entry screen.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited