PhoneLookupDataResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PhoneLookupDataResponse({required String subject, required String channel, required String verificationToken, required int expiresAt, required bool hasAccount})
-
const
-
PhoneLookupDataResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- channel → String
-
final
- expiresAt → int
-
final
- hasAccount → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String
-
final
- verificationToken → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited