RegisterConfig class
Register
Constructors
- RegisterConfig({String title = 'Register', Widget? firstNamePrefix, Widget? lastNamePrefix, Widget? emailPrefix, Widget? passwordPrefix, Widget? confirmPasswordPrefix, String subtitle = 'Enter your details to create an account', String buttonLabel = 'Create account', String alreadyHaveAccountLabel = 'Already have an account?', String loginLabel = 'Login'})
-
const
Properties
- alreadyHaveAccountLabel → String
-
The label text for the already have account button.
final
-
The button label for the verify button.
final
- confirmPasswordPrefix → Widget?
-
final
- emailPrefix → Widget?
-
final
- firstNamePrefix → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastNamePrefix → Widget?
-
final
- loginLabel → String
-
The label text for the login button.
final
- passwordPrefix → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String
-
The subtitle text with {{phone}} placeholder for the phone number.
Example: 'Enter the code sent to {{phone}}'
final
- title → String
-
The title text for the otp verification screen.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited