User class abstract

Represents an authenticated user decoded from the JWT payload and/or fetched from GET /users/me.

Available extensions
Annotations
  • @freezed

Constructors

User({required String id, required int onboardingStep, required bool isEmailVerified, required bool isPhoneVerified, required bool isProfileCompleted, required String status, required String displayName, String? username, String? email, String? phoneNumber, String? countryCode, @Default.new([]) List<String> roles})
const
factory
User.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $UserCopyWith<User>
Create a copy of User with the given fields replaced by the non-null parameter values.
no setterinherited
countryCode String?
no setterinherited
displayName String
no setterinherited
email String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
isEmailVerified bool
no setterinherited
isPhoneVerified bool
no setterinherited
isProfileCompleted bool
no setterinherited
onboardingStep int
no setterinherited
phoneNumber String?
no setterinherited
roles List<String>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
no setterinherited
username String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_User value)) → TResult

Available on User, provided by the UserPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_User value)?) → TResult?

Available on User, provided by the UserPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_User value)?, {required TResult orElse()}) → TResult

Available on User, provided by the UserPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, int onboardingStep, bool isEmailVerified, bool isPhoneVerified, bool isProfileCompleted, String status, String displayName, String? username, String? email, String? phoneNumber, String? countryCode, List<String> roles)?, {required TResult orElse()}) → TResult

Available on User, provided by the UserPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this User to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, int onboardingStep, bool isEmailVerified, bool isPhoneVerified, bool isProfileCompleted, String status, String displayName, String? username, String? email, String? phoneNumber, String? countryCode, List<String> roles)) → TResult

Available on User, provided by the UserPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, int onboardingStep, bool isEmailVerified, bool isPhoneVerified, bool isProfileCompleted, String status, String displayName, String? username, String? email, String? phoneNumber, String? countryCode, List<String> roles)?) → TResult?

Available on User, provided by the UserPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited