UserDetailsConfig class

Enter user details

Constructors

UserDetailsConfig({String title = 'Create your account', String subtitle = 'Enter your details to create an account', String buttonLabel = 'Create account', bool requireEmail = false, bool emailLookup = false, Widget? firstNamePrefix, Widget? lastNamePrefix, Widget? emailPrefix})
const

Properties

buttonLabel String
The button label for the create account button.
final
emailLookup bool
If true, checks on blur whether the email belongs to an existing account.
final
emailPrefix Widget?
The prefix widget for the email input (supports SVG, Icon, etc.).
final
firstNamePrefix Widget?
The prefix widget for the first name input (supports SVG, Icon, etc.).
final
hashCode int
The hash code for this object.
no setterinherited
lastNamePrefix Widget?
The prefix widget for the last name input (supports SVG, Icon, etc.).
final
requireEmail bool
Whether to require email input.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String
The subtitle text for the user details screen.
final
title String
The title text for the user details screen.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited