FxApiClient class
Configured Dio HTTP client used by all foundation services.
Base URL is built from FxConfig.apiBaseUrl + FxConfig.apiVersion. All interceptors are registered here.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{required FxConfig config, required FxTokenManager tokenManager, required Future< bool> onUnauthorized()}) → Dio