FxTokenManager class

Holds the access token in memory only — never persisted to disk.

The refresh token is handled separately in AuthStorage.

Constructors

FxTokenManager()

Properties

accessToken String?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasToken bool
no setter
isExpired bool
True if there is no token or its JWT expiry claim has passed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearToken() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setToken(String token) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited