FxNotificationsState class
- Available extensions
- Annotations
-
- @CopyWith.new()
Constructors
-
FxNotificationsState({List<
FxNotification> notifications = const [], int unreadCount = 0, bool isLoading = false, String? error, bool hasNextPage = false, int currentPage = 1}) -
const
Properties
- copyWith → FxNotificationsStateCopyWithFn
-
Available on FxNotificationsState, provided by the FxNotificationsStateCopyWith extension
no setter - currentPage → int
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNextPage → bool
-
final
- isLoading → bool
-
final
-
notifications
→ List<
FxNotification> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unreadCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited