blueprint_theme library

Theme contracts, tokens, and ThemeController (Riverpod).

import 'package:blueprint_flutter_core/blueprint_theme.dart';

Classes

FxColorMode
Holds the light and dark variants of a single color token. Use resolve to get the correct color for the current brightness.
FxColors
Blueprint contract for brand colors.
FxComponentTheme
Blueprint contract for Material sub-theme builders.
FxSizes
Spacing, radius, and elevation constants.
FxTheme
Blueprint theme builder.
FxThemeController
FxThemeControllerProvider
FxThemeData
Blueprint contract for Material sub-theme builders.
FxTypography
Blueprint contract for typography.