FxTypography class abstract
Blueprint contract for typography.
Extend this in app/theme/app_typography.dart.
Every style here is applied to Material TextTheme by FxTheme.build.
colors is brightness-resolved before being passed in — use colors.textPrimary
etc. directly in your TextStyle definitions.
- Inheritance
-
- Object
- ThemeExtension<
FxTypography> - FxTypography
Constructors
- FxTypography({required FxColors colors, required FxSizes sizes})
-
const
Properties
- bodyFontFamily → String
-
no setter
- bodyLarge → TextStyle
-
no setter
- bodyMedium → TextStyle
-
no setter
- bodySmall → TextStyle
-
no setter
- caption → TextStyle
-
no setter
- captionMedium → TextStyle
-
no setter
- captionSmall → TextStyle
-
no setter
- colors → FxColors
-
final
- displayLarge → TextStyle
-
no setter
- displayMedium → TextStyle
-
no setter
- displaySmall → TextStyle
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- headlineFontFamily → String
-
no setter
- headlineLarge → TextStyle
-
no setter
- headlineMedium → TextStyle
-
no setter
- headlineSmall → TextStyle
-
no setter
- labelLarge → TextStyle
-
no setter
- labelMedium → TextStyle
-
no setter
- labelSmall → TextStyle
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizes → FxSizes
-
final
- titleLarge → TextStyle
-
no setter
- titleMedium → TextStyle
-
no setter
- titleSmall → TextStyle
-
no setter
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{FxColors? colors, FxSizes? sizes}) → FxTypography -
Returns a copy with updated fields.
FxTheme.build calls this with brightness-resolved
colors.override -
lerp(
covariant FxTypography? other, double t) → FxTypography -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited