Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
absolute(
DateTime dateTime) → String - e.g. "Mar 5, 2026"
-
date(
DateTime dateTime) → String - e.g. "05/03/2026"
-
dateTime(
DateTime dt) → String - e.g. "Mar 5, 2026 14:30"
-
relative(
DateTime dateTime) → String - e.g. "2 hours ago", "3 days ago", "just now"
-
time(
DateTime dateTime) → String - e.g. "14:30"
-
tryParse(
String? value) → DateTime?