FxDockStyle class

Visual and layout tokens for FxDock.

Available extensions
Annotations
  • @CopyWith.new()

Constructors

FxDockStyle({double? height, NotchedShape? notchShape, Color? shadowColor, FxTileBuilder<FxPane>? itemBuilder, Color? backgroundColor, EdgeInsetsGeometry padding = EdgeInsets.zero, Clip clipBehavior = Clip.none, Color? surfaceTintColor, double spacing = 0.0, FxRowTileStyle tileStyle = const FxRowTileStyle(), double elevation = 4, double notchMargin = 0.0, MainAxisSize mainAxisSize = MainAxisSize.max, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, Widget animationBuilder(Widget, Animation<double>) = AnimatedSwitcher.defaultTransitionBuilder, Duration animationDuration = const Duration(milliseconds: 300)})
const

Properties

animationBuilder Widget Function(Widget, Animation<double>)
final
animationDuration Duration
final
backgroundColor Color?
final
clipBehavior Clip
final
copyWith FxDockStyleCopyWithFn

Available on FxDockStyle, provided by the FxDockStyleCopyWith extension

no setter
crossAxisAlignment CrossAxisAlignment
final
elevation double
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
itemBuilder FxTileBuilder<FxPane>?
final
mainAxisAlignment MainAxisAlignment
final
mainAxisSize MainAxisSize
final
notchMargin double
final
notchShape NotchedShape?
final
padding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color?
final
spacing double
final
surfaceTintColor Color?
final
tileStyle FxRowTileStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited