FxDrawerStyle class
Visual and layout tokens for FxDrawer and FxDrawer.end.
- Available extensions
- Annotations
-
- @CopyWith.new()
Constructors
-
FxDrawerStyle({double? width, ShapeBorder? shape, FxSafeAreaInsets safeArea = const FxSafeAreaInsets(top: false), double elevation = 4.0, Color? shadowColor, Color? backgroundColor, Color? surfaceTintColor, EdgeInsetsGeometry padding = EdgeInsets.zero, ScrollPhysics physics = const BouncingScrollPhysics(), bool shrinkWrap = false, Widget headerBuilder(BuildContext)?, FxTileStyle tileStyle = const FxTileStyle(), FxTileBuilder<
FxTile> ? tileBuilder, Widget separatorBuilder = const SizedBox.shrink(), Widget animationBuilder(Widget, Animation<double> ) = AnimatedSwitcher.defaultTransitionBuilder, Duration animationDuration = const Duration(milliseconds: 300)}) -
const
Properties
-
animationBuilder
→ Widget Function(Widget, Animation<
double> ) -
final
- animationDuration → Duration
-
final
- backgroundColor → Color?
-
final
- copyWith → FxDrawerStyleCopyWithFn
-
Available on FxDrawerStyle, provided by the FxDrawerStyleCopyWith extension
no setter - elevation → double
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBuilder → Widget Function(BuildContext)?
-
final
- padding → EdgeInsetsGeometry
-
final
- physics → ScrollPhysics
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safeArea → FxSafeAreaInsets
-
final
- separatorBuilder → Widget
-
final
- shadowColor → Color?
-
final
- shape → ShapeBorder?
-
final
- shrinkWrap → bool
-
final
- surfaceTintColor → Color?
-
final
-
tileBuilder
→ FxTileBuilder<
FxTile> ? -
final
- tileStyle → FxTileStyle
-
final
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited