FxFormGroup class
- Implementers
Constructors
-
FxFormGroup(Map<
String, FxFormControl> controls) -
const
Properties
-
controls
→ Map<
String, FxFormControl> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
Map< String, FxFormControl> controls) → FxFormGroup -
dispose(
) → void -
getControl(
String key) → FxFormControl -
initState(
) → FxFormGroup -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
String key, String value) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateControl(
String key, FxFormControl updater(FxFormControl value)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited