FxOverlayOptions<T> class
- Annotations
Constructors
- FxOverlayOptions.builder({String? title, Widget heading(BuildContext context)?, required Widget builder(BuildContext context)})
-
factory
-
FxOverlayOptions.multiSelect({String? title, Widget heading(BuildContext context)?, required List<
T> ? items, List<T> ? favoriteItems, FxOverlayTile<T> itemTile = const FxOverlayTile(), Stream<List< ? itemsAsStream, List<T> >T> ? selectedItems, String searchHint = 'Search...', FxOverlaySearchCallback<T> ? onSearch, FxOverlayItemComparer<T> ? itemComparer, bool closeOnSelect = false, String confirmLabel = 'Done', String? clearLabel = 'Clear', int minSelection = 0, int? maxSelection}) -
factory
-
FxOverlayOptions.singleSelect({String? title, Widget heading(BuildContext context)?, required List<
T> ? items, List<T> ? favoriteItems, Stream<List< ? itemsAsStream, T? selectedItem, FxOverlayTile<T> >T> itemTile = const FxOverlayTile(), String searchHint = 'Search...', FxOverlaySearchCallback<T> ? onSearch, FxOverlayItemComparer<T> ? itemComparer, bool closeOnSelect = true}) -
factory
Properties
- builder → Widget Function(BuildContext context)?
-
final
- clearLabel → String?
-
final
- closeOnSelect → bool
-
final
- confirmLabel → String
-
final
-
favoriteItems
→ List<
T> ? -
final
-
final
- hasFavorites → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSearch → bool
-
no setter
- hasSelection → bool
-
no setter
- heading → Widget Function(BuildContext context)?
-
final
- isBuilder → bool
-
no setter
- isListOverlay → bool
-
no setter
- isMultiSelect → bool
-
no setter
- isSingleSelect → bool
-
no setter
-
itemComparer
→ FxOverlayItemComparer<
T> ? -
final
-
items
→ List<
T> ? -
final
-
itemsAsStream
→ Stream<
List< ?T> > -
final
-
itemTile
→ FxOverlayTile<
T> -
final
- maxSelection → int?
-
final
- minSelection → int
-
final
- mode → FxOverlayMode
-
final
-
onSearch
→ FxOverlaySearchCallback<
T> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchHint → String?
-
final
- selectedItem → T?
-
no setter
-
selectedItems
→ List<
T> ? -
final
- title → String?
-
final
Methods
-
asMultiSelect(
{String confirmLabel = 'Done', String? clearLabel = 'Clear', int minSelection = 0, int? maxSelection}) → FxOverlayOptions< T> -
asSingleSelect(
) → FxOverlayOptions< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited