FxOverlaySelectionState<T> class
Mutable selection state for FxOverlayList.
Constructors
-
FxOverlaySelectionState(FxOverlayOptions<
T> options)
Properties
- canConfirm → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMultiSelect → bool
-
no setter
-
options
→ FxOverlayOptions<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedValues
→ List<
T> -
no setter
Methods
-
canToggle(
T item) → bool -
clear(
) → void -
confirm(
) → List< T> -
isSelected(
T item) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toggle(
T item) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited