FxOverlayTile<T> class
- Annotations
Constructors
-
FxOverlayTile({String title(T item)?, FxOverlayTileBuilder<
T> ? builder, String subtitle(T item)?, FxOverlayTileWidgetBuilder<T> ? titleBuilder, FxOverlayTileWidgetBuilder<T> ? leadingBuilder, FxOverlayTileWidgetBuilder<T> ? subtitleBuilder, FxOverlayTileWidgetBuilder<T> ? trailingBuilder}) -
const
Properties
-
builder
→ FxOverlayTileBuilder<
T> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
leadingBuilder
→ FxOverlayTileWidgetBuilder<
T> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String Function(T item)?
-
final
-
subtitleBuilder
→ FxOverlayTileWidgetBuilder<
T> ? -
final
- title → String Function(T item)?
-
final
-
titleBuilder
→ FxOverlayTileWidgetBuilder<
T> ? -
final
-
trailingBuilder
→ FxOverlayTileWidgetBuilder<
T> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited