FxOverlayTileThemeData class
Constructors
- FxOverlayTileThemeData({EdgeInsets? margin, VisualDensity? visualDensity = VisualDensity.compact, bool dense = false, ShapeBorder? shape, EdgeInsets? contentPadding, double? minTileHeight, double? horizontalTitleGap, Color foregroundColor(bool isSelected)?, TextStyle? titleStyle, TextStyle? subtitleStyle, Color backgroundColor(bool isSelected)?, bool? showSelectionIndicator})
-
const
Properties
- backgroundColor → Color Function(bool isSelected)?
-
final
- contentPadding → EdgeInsets?
-
final
- dense → bool
-
final
- foregroundColor → Color Function(bool isSelected)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalTitleGap → double?
-
final
- margin → EdgeInsets?
-
final
- minTileHeight → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → ShapeBorder?
-
final
- showSelectionIndicator → bool?
-
final
- subtitleStyle → TextStyle?
-
final
- titleStyle → TextStyle?
-
final
- visualDensity → VisualDensity?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited