FxOverlayView<T> class
- Inheritance
-
- Mixed-in types
-
Methods
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
override
-
createElement()
→ StatelessElement
-
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<T>([T? result])
→ void
-
Pops the current route off the stack.
inherited
-
push(String route)
→ void
-
Pushes a named route onto the stack.
inherited
-
pushAndClearStack(String route)
→ void
-
Clears the entire stack and pushes a named route.
inherited
-
pushReplace(String route)
→ void
-
Replaces the current route with a named route.
inherited
-
setToolkitContext(BuildContext ctx)
→ void
-
inherited
-
showFxBottomSheet<T>({bool cancelable = true, bool allowFullHeight = true, double maxChildSize = 0.9, double minChildSize = 0.25, double initialChildSize = 0.5, required FxOverlayData<T> data})
→ Future<T?>
-
Shows the blueprint bottom sheet.
inherited
-
showFxDialog<T>({bool cancelable = true, FxDialogStyle style = FxDialogStyle.center, required FxOverlayData<T> data})
→ Future<T?>
-
Shows the blueprint dialog.
inherited
-
showSnackBar(SnackBar snackBar)
→ void
-
Shows a snack bar.
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toggleTheme(WidgetRef ref)
→ void
-
Toggles the theme between light and dark mode.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited
-
unfocus()
→ void
-
Unfocuses the current focus node.
inherited