FxPaneDividerStyle class

Visual config for FxPaneType.divider rows.

Available extensions
Annotations

Constructors

FxPaneDividerStyle({Color? color, TextStyle? textStyle, BoxDecoration? decoration, TextAlign align = TextAlign.start, EdgeInsets padding = EdgeInsets.zero, EdgeInsets margin = EdgeInsets.zero, double spacing = 0, double dashSpace = 0, double dashWidth = 0, double strokeWidth = 1})
const

Properties

align TextAlign
final
color Color?
final
copyWith FxPaneDividerStyleCopyWithFn

Available on FxPaneDividerStyle, provided by the FxPaneDividerStyleCopyWith extension

no setter
dashSpace double
final
dashWidth double
final
decoration BoxDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsets
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
final
strokeWidth double
final
textStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited