FxPhoneInput class
Phone number input with country dial code prefix.
onChanged receives the selected country, the national digits only (no
spaces), and an optional third argument parsed when libphonenumber accepts
the combined dial code + digits (otherwise null).
Declare the callback with an optional positional third parameter, even if
you ignore it, for example (country, phone, [_]) { ... } or
(country, phone, [parsed]) { ... }.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FxPhoneInput
Constructors
-
FxPhoneInput({Key? key, FxPhoneInputChanged? onChanged, FormFieldValidator<
String> ? validator, FxOverlayStyle overlayStyle = FxOverlayStyle.modal, String? label, String hint = 'Enter your phone number', FxFlagShape flagShape = FxFlagShape.circle, double flagSize = 28, String initialCountryCode = 'NG', TextEditingController? controller, TextInputAction textInputAction = TextInputAction.next, FocusNode? focusNode}) -
const
Properties
- controller → TextEditingController?
-
final
- flagShape → FxFlagShape
-
final
- flagSize → double
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String
-
final
- initialCountryCode → String
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- onChanged → FxPhoneInputChanged?
-
final
- overlayStyle → FxOverlayStyle
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textInputAction → TextInputAction
-
final
-
validator
→ FormFieldValidator<
String> ? -
final
Methods
-
createElement(
) → ConsumerStatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → ConsumerState< FxPhoneInput> - Creates the mutable state for this widget at a given location in the tree.
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited