FxPhoneInputConfig class
- Annotations
Constructors
- FxPhoneInputConfig({FxPhoneInputLayout layout = FxPhoneInputLayout.integrated, FxFieldOptions options = const FxFieldOptions(keyboardType: TextInputType.phone), FxFieldOptions countryOptions = const FxFieldOptions(), InputDecoration decoration = const InputDecoration(), FxOverlayType overlayType = FxOverlayType.dialog})
-
const
Properties
- countryOptions → FxFieldOptions
-
final
- decoration → InputDecoration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → FxPhoneInputLayout
-
final
- options → FxFieldOptions
-
final
- overlayType → FxOverlayType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited