FxShellScope class
Inherited scope for imperative shell actions from any descendant (including nested Scaffolds inside FxPane bodies).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- ProxyWidget
- InheritedWidget
- FxShellScope
Constructors
-
FxShellScope({Key? key, required GlobalKey<
ScaffoldState> scaffoldKey, required bool hasDrawer, required bool hasEndDrawer, required bool canPopShell, required bool popShell(), required Widget child}) -
const
Properties
- canPopShell → bool
-
Whether shell pane history can be popped (FxShellCtrl.pop).
final
- child → Widget
-
The widget below this widget in the tree.
finalinherited
- hasDrawer → bool
-
Whether the drawer is supported.
Example:
final
- hasEndDrawer → bool
-
Whether the end drawer is supported.
Example:
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDrawerOpen → bool
-
Whether the drawer is open.
Example:
no setter
- isEndDrawerOpen → bool
-
Whether the end drawer is open.
Example:
no setter
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- popShell → bool Function()
-
Pops one pane from shell history. Returns
falseif canPopShell is false.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scaffoldKey
→ GlobalKey<
ScaffoldState> -
The GlobalKey for the ScaffoldState.
Example:
final
Methods
-
canHandleBack(
BuildContext context) → bool - Whether back would close a drawer, pop shell, or pop Navigator.
-
closeAnyDrawer(
) → void - Closes whichever drawer is open; no-op if none. Example:
-
closeDrawer(
) → void - Closes the drawer if it is open. Example:
-
closeEndDrawer(
) → void - Closes the end drawer if it is open. Example:
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
exitApp(
) → void -
Call when handleBack returns
false(e.g. exit app). -
handleBack(
BuildContext context) → bool -
System back order: drawer → shell history → route →
falseif nothing left. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openDrawer(
) → void - Opens the drawer if it is not open. Example:
-
openEndDrawer(
) → void - Opens the end drawer if it is not open. Example:
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateShouldNotify(
covariant FxShellScope oldWidget) → bool -
Whether the framework should notify widgets that inherit from this widget.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf(
BuildContext context) → FxShellScope? - Returns the FxShellScope if it exists, otherwise returns null. Use this to access the FxShellScope from any descendant widget. Example:
-
of(
BuildContext context) → FxShellScope - Returns the FxShellScope if it exists, otherwise throws an assertion. Use this to access the FxShellScope from any descendant widget. Example: