FxTile class
Constructors
-
FxTile({required String key, required String title, String? subtitle, FxTileBuilder<
FxTile> ? tileBuilder, FxTileIconBuilder? iconBuilder, FxTileTrailingBuilder? trailingBuilder, bool isExpanded = true}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasIcon → bool
-
True if the tile has an icon builder.
no setter
- hasTrailing → bool
-
True if the tile has a trailing builder.
no setter
- iconBuilder → FxTileIconBuilder?
-
final
- isExpanded → bool
-
final
- key → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
final
-
tileBuilder
→ FxTileBuilder<
FxTile> ? -
final
- title → String
-
final
- trailingBuilder → FxTileTrailingBuilder?
-
final
Methods
-
buildIcon(
bool isActive, double? size, Color? color) → Widget? -
Builds the icon for the tile.
@param
isActive- True if the tile is active. @paramsize- The size of the icon. @paramcolor- The color of the icon. @return The icon widget. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited