FxTileStyle class
- Implementers
- Annotations
Constructors
-
FxTileStyle({FxTileState<
double?> ? iconSize, FxTileState<TextStyle> ? textStyle, FxTileState<TextStyle> ? subtitleStyle, FxTileState<Color> ? iconColor, FxTileState<Color> ? backgroundColor, EdgeInsetsGeometry padding = EdgeInsets.zero, Duration duration = const Duration(milliseconds: 300), Duration? reverseDuration, Curve switchInCurve = Curves.linear, Curve switchOutCurve = Curves.linear, Widget transitionBuilder(Widget, Animation<double> ) = AnimatedSwitcher.defaultTransitionBuilder, Widget layoutBuilder(Widget?, List<Widget> ) = AnimatedSwitcher.defaultLayoutBuilder}) -
const
Properties
-
backgroundColor
→ FxTileState<
Color> ? -
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
iconColor
→ FxTileState<
Color> ? -
final
-
iconSize
→ FxTileState<
double?> ? -
final
-
layoutBuilder
→ Widget Function(Widget?, List<
Widget> ) -
final
- padding → EdgeInsetsGeometry
-
final
- reverseDuration → Duration?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subtitleStyle
→ FxTileState<
TextStyle> ? -
final
- switchInCurve → Curve
-
final
- switchOutCurve → Curve
-
final
-
textStyle
→ FxTileState<
TextStyle> ? -
final
-
transitionBuilder
→ Widget Function(Widget, Animation<
double> ) -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited