Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
initials(
String fullName, {int maxLetters = 2}) → String - Returns initials from a full name (e.g. "John Doe" → "JD").
-
maskEmail(
String email) → String -
Masks a string leaving
visibleEndcharacters visible. e.g. maskEmail("john@example.com") → "j***@example.com" -
maskPhoneNumber(
String phone, {int visibleStartDigits = 0, int visibleEndDigits = 4, String maskChar = '•'}) → String - Masks digit characters for safe display.
-
titleCase(
String value) → String - Capitalises the first letter of each word.
-
truncate(
String value, int maxLength) → String -
Truncates text with an ellipsis if it exceeds
maxLength.